#!/usr/bin/env python
# -*- coding: utf-8 -*-
#
#       changeDictionaryAllRegions.py
#
#           changeDictionaryAllRegionsDictの内容に従って、各regionに
#           changeDictionaryRegionsDictを作り、各regionに対し、changeDictionaryを
#           実行してdictionaryを書き換える。
#
#   13/01/18    file名を受けて実行する様に修正
#      06/01    helpを追加
#

import os
import sys
import glob
import getFoamContents
import setFoamContents

caseDir = ""
contentsDict = ""

#
#  getEachRegions
#    AllregionsDictから書き換えるregionを取得
def getEachRegions(name):
    global caseDir, contentsDict
    fileName = caseDir + "/system/" + name
    f=open(fileName)
    contentsDict = f.read()
    f.close()
    p = getFoamContents.skipFoamFileMem(contentsDict, 0)
    regions = []
    while p<len(contentsDict):
        [[region, dummy], p] = getFoamContents.getNextKeywordAndContentsMem(contentsDict, p)
        if region != "":
            regions.append(region)
    return regions

#
#  setChangeDictionaryRegionsDict
#    各reginのchangeDictionaryDictを作成し、各regionにセット
def setChangeDictionaryRegionsDict(regions):
    global caseDir, contentsDict
    error = ""
    #errorチェック
    for name in regions:
        fileName = fileName = caseDir + "/system/" + name
        if len(glob.glob(fileName)) == 0:
            error = u"region「" + name + u"」が存在しません。"
            break
    if error != "":
        return error

    #foamFile作成
    foamFile = setFoamContents.makeFoamHeader()
    foamFile += setFoamContents.makeFoamFile("2.0", "ascii", "dictionary", "system", "changeDictionaryDict")
    footer = setFoamContents.makeFooter()

    #changeDictionaryDictを作成
    p=0
    for name in regions:
        [contents, p] = getFoamContents.getKeywordContentsMem(name, contentsDict, p)
        fileName = caseDir + "/system/" + name + "/changeDictionaryDict"
        f=open(fileName, "w")
        f.write(foamFile + contents + footer)
        f.close()
    return error

#
#  runEachChangeDictionary
#    各regionのchangeDictionaryを実行
def runEachChangeDictionary(regions):
    for name in regions:
        comm = "changeDictionary -region " + name
        print comm
        os.system(comm)

#
#  printHelp
#    helpを出力
def printHelp():
    print """
*** changeDictionaryAllRegions.pyの使い方 ***

<概要>
multiRegionモデルの境界条件を設定するコマンド。
境界条件は、dictFileの指示に従って設定される。

<使い方>
changeDictionaryAllRegionsDict.py [dictFile] [option]

[dictFile]
    dictFileの指示に従って境界条件を設定する。
    省略時はchangeDictionaryAllRegionsDictが使われる

[option]
    -h          helpを表示
    -help       　"
    --help        "

***********************************************
"""


#
#  メイン
#

if len(sys.argv) > 1:
    comm = sys.argv[1]
    if comm == "-h" or comm == "--help" or comm == "-help":
        printHelp()
        exit()
    else:
        fileName = comm
else:
    fileName = "changeDictionaryAllRegionsDict"
#  caseDirを取得
caseDir = os.getcwd()
#  変更するregionを取得
regions = getEachRegions(fileName)
#  changeDictionaryを作成し各regionにセット
error = setChangeDictionaryRegionsDict(regions)
#  changeDictionaryを実行
if error == "":
    runEachChangeDictionary(regions)
else:
    print error.encode("utf-8")

