#!/usr/bin/env python
# -*- coding: utf-8 -*-
#
#   fileOperationInRegionDialog.py
#
#       各region内のfile操作
#
#   13/01/06    新規作成
#      01/07    DBの場所（defaultの値）を変更
#      01/09    固体の材料選択を修正
#      01/12    DBの場所（defaultの値）を変更
#      01/30    全region削除ボタンを追加
#      02/21    材料設定をlistBox→listCtrlに変更
#      04/07    バグ修正（材料DB内のfile編集ボタンでエラー発生）
#      04/11    file名変更ボタン追加
#      05/01    csvFileで一括設定を追加
#      05/14    csvFile設定した後、表示が変わらないので、表示も変えるよう変更
#      05/19    setMaterialToRegionを修正（copy→delete後、copy）
#      05/20    solidの物性値設定をOF2.2.0に対応
#      05/21    OFversionチェックをinitialize内に統一
#      05/25    checkMaterialDBDirのチェック方法修正
#      05/29    regionを削除した場合の処理を追加、戻すボタンを追加
#      06/22    全region削除ボタン削除
#      07/14    DBフォルダ内にfileが無かった場合、fileをコピーする。
#      09/01    liveDVDで起動したとき、
#                   setMultiRegionでDBdirが設定できない、ゴミ箱が無いエラーを修正
#      09/20    変更ボタンの設定が削除になっていたのを修正
#      10/04    iniTimeの取得をcurrTimeに変更
#


# generated by wxGlade 0.6.5 on Fri Jan  4 17:54:48 2013

#------------コード生成後の変更内容-----------------------
#
#  ・アイコンのdirを変更（絶対path→相対path）
#       ./icons/***　形式に変更
#

import wx
import os
import sys
import glob
import gio
import csv
import getFoamContents
import pyTreeFoam
import getOpenFolderDDialog
import inputTextDDialog
from getOpenFileDDialog import Show as getOpenFileDDialogShow

# begin wxGlade: extracode
# end wxGlade

OFversion = ""                          #OFのバージョン
solidProperties = ""                    #materialDBのフォルダ名
multiRegion_data = os.environ["TreeFoamPath"] + "/data/multiRegion_data"
solidPhysicalDBdir = os.environ["HOME"] + "/OpenFOAM/multiRegionDB/solid/thermophysicalProperties"
iniDBdata = os.environ["TreeFoamPath"] + "/data/multiRegionDB/solid/thermophysicalProperties"
fluidRegions = []
solidRegions = []
iniTime = ""
timeFiles = []
timeFluidFiles = []
timeSolidFiles = []
constantFiles = []
constantFluidFiles = []
constantSolidFiles = []
solidPhysicalDB = []
constantSolidPhysical = []              #設定されている材料
constantSolidPhysicalReq = []           #材料設定の候補
systemFiles = []
systemFluidFiles = []
systemSolidFiles = []




def Show():
    #materialDBDirをチェックし、dirが存在しないならば、作成する。
    checkMaterialDBDir()
    #初期化
    initialize()
    #dialog表示
    app = wx.PySimpleApp(0)
    wx.InitAllImageHandlers()
    frame_1 = MyFrame(None, -1, "")
    app.SetTopWindow(frame_1)
    frame_1.Show()
    app.MainLoop()

class MyFrame(wx.Frame):
    def __init__(self, *args, **kwds):

        savePath = os.getcwd()
        treeFoamPath = os.getenv("TreeFoamPath")
        os.chdir(treeFoamPath)

        # begin wxGlade: MyFrame.__init__
        kwds["style"] = wx.DEFAULT_FRAME_STYLE
        wx.Frame.__init__(self, *args, **kwds)
        self.label_1 = wx.StaticText(self, -1, u"各regionのfile操作")
        self.notebook_1 = wx.Notebook(self, -1, style=0)
        self.notebook_1_pane_1 = wx.Panel(self.notebook_1, -1)
        self.list_box_1 = wx.ListBox(self.notebook_1_pane_1, -1, choices=[], style=wx.LB_MULTIPLE)
        self.button_17 = wx.Button(self.notebook_1_pane_1, -1, u"変更")
        self.label_24 = wx.StaticText(self.notebook_1_pane_1, -1, u"file名変更")
        self.button_1 = wx.Button(self.notebook_1_pane_1, -1, u"削除")
        self.label_2 = wx.StaticText(self.notebook_1_pane_1, -1, u"選択fileを削除")
        self.sizer_4_staticbox = wx.StaticBox(self.notebook_1_pane_1, -1, "file(region0)")
        self.button_2 = wx.Button(self.notebook_1_pane_1, -1, u"配布>>")
        self.button_20 = wx.Button(self.notebook_1_pane_1, -1, u"<<戻す")
        self.button_3 = wx.Button(self.notebook_1_pane_1, -1, u"配布>>")
        self.button_21 = wx.Button(self.notebook_1_pane_1, -1, u"<<戻す")
        self.label_3 = wx.StaticText(self.notebook_1_pane_1, -1, "file")
        self.list_box_2 = wx.ListBox(self.notebook_1_pane_1, -1, choices=[], style=wx.LB_MULTIPLE)
        self.button_11 = wx.Button(self.notebook_1_pane_1, -1, u"変更")
        self.label_15 = wx.StaticText(self.notebook_1_pane_1, -1, u"file名変更")
        self.button_4 = wx.Button(self.notebook_1_pane_1, -1, u"削除")
        self.label_4 = wx.StaticText(self.notebook_1_pane_1, -1, u"選択fileを削除")
        self.label_5 = wx.StaticText(self.notebook_1_pane_1, -1, "region")
        self.list_box_3 = wx.ListBox(self.notebook_1_pane_1, -1, choices=[])
        self.button_5 = wx.Button(self.notebook_1_pane_1, -1, u"編集")
        self.label_6 = wx.StaticText(self.notebook_1_pane_1, -1, u"file内容確認")
        self.sizer_8_staticbox = wx.StaticBox(self.notebook_1_pane_1, -1, u"流体")
        self.label_7 = wx.StaticText(self.notebook_1_pane_1, -1, "file")
        self.list_box_4 = wx.ListBox(self.notebook_1_pane_1, -1, choices=[], style=wx.LB_MULTIPLE)
        self.button_12 = wx.Button(self.notebook_1_pane_1, -1, u"変更")
        self.label_16 = wx.StaticText(self.notebook_1_pane_1, -1, u"file名変更")
        self.button_6 = wx.Button(self.notebook_1_pane_1, -1, u"削除")
        self.label_8 = wx.StaticText(self.notebook_1_pane_1, -1, u"選択fileを削除")
        self.label_9 = wx.StaticText(self.notebook_1_pane_1, -1, "region")
        self.list_box_5 = wx.ListBox(self.notebook_1_pane_1, -1, choices=[])
        self.button_7 = wx.Button(self.notebook_1_pane_1, -1, u"編集")
        self.label_10 = wx.StaticText(self.notebook_1_pane_1, -1, u"file内容確認")
        self.sizer_9_staticbox = wx.StaticBox(self.notebook_1_pane_1, -1, u"固体")
        self.notebook_1_pane_2 = wx.Panel(self.notebook_1, -1)
        self.list_box_c1 = wx.ListBox(self.notebook_1_pane_2, -1, choices=[], style=wx.LB_MULTIPLE)
        self.button_24 = wx.Button(self.notebook_1_pane_2, -1, u"変更")
        self.label_25 = wx.StaticText(self.notebook_1_pane_2, -1, u"file名変更")
        self.button_c1 = wx.Button(self.notebook_1_pane_2, -1, u"削除")
        self.label_2_copy = wx.StaticText(self.notebook_1_pane_2, -1, u"選択fileを削除")
        self.sizer_4_copy_staticbox = wx.StaticBox(self.notebook_1_pane_2, -1, "file(region0)")
        self.button_c2 = wx.Button(self.notebook_1_pane_2, -1, u"配布>>")
        self.button_22 = wx.Button(self.notebook_1_pane_2, -1, u"<<戻す")
        self.button_c3 = wx.Button(self.notebook_1_pane_2, -1, u"配布>>")
        self.button_23 = wx.Button(self.notebook_1_pane_2, -1, u"<<戻す")
        self.label_3_copy = wx.StaticText(self.notebook_1_pane_2, -1, "file")
        self.list_box_c2 = wx.ListBox(self.notebook_1_pane_2, -1, choices=[], style=wx.LB_MULTIPLE)
        self.button_13 = wx.Button(self.notebook_1_pane_2, -1, u"変更")
        self.label_18 = wx.StaticText(self.notebook_1_pane_2, -1, u"file名変更")
        self.button_c4 = wx.Button(self.notebook_1_pane_2, -1, u"削除")
        self.label_4_copy = wx.StaticText(self.notebook_1_pane_2, -1, u"選択fileを削除")
        self.label_5_copy = wx.StaticText(self.notebook_1_pane_2, -1, "region")
        self.list_box_c3 = wx.ListBox(self.notebook_1_pane_2, -1, choices=[])
        self.button_c5 = wx.Button(self.notebook_1_pane_2, -1, u"編集")
        self.label_6_copy = wx.StaticText(self.notebook_1_pane_2, -1, u"file内容確認")
        self.sizer_8_copy_staticbox = wx.StaticBox(self.notebook_1_pane_2, -1, u"流体")
        self.label_7_copy = wx.StaticText(self.notebook_1_pane_2, -1, "file")
        self.list_box_c4 = wx.ListBox(self.notebook_1_pane_2, -1, choices=[], style=wx.LB_MULTIPLE)
        self.button_14 = wx.Button(self.notebook_1_pane_2, -1, u"変更")
        self.label_19 = wx.StaticText(self.notebook_1_pane_2, -1, u"file名変更")
        self.button_c6 = wx.Button(self.notebook_1_pane_2, -1, u"削除")
        self.label_8_copy = wx.StaticText(self.notebook_1_pane_2, -1, u"選択fileを削除")
        self.label_9_copy = wx.StaticText(self.notebook_1_pane_2, -1, "region")
        self.list_box_c5 = wx.ListBox(self.notebook_1_pane_2, -1, choices=[])
        self.button_c7 = wx.Button(self.notebook_1_pane_2, -1, u"編集")
        self.label_10_copy = wx.StaticText(self.notebook_1_pane_2, -1, u"file内容確認")
        self.sizer_39_staticbox = wx.StaticBox(self.notebook_1_pane_2, -1, u"固体")
        self.notebook_1_pane_3 = wx.Panel(self.notebook_1, -1)
        self.list_box_s1 = wx.ListBox(self.notebook_1_pane_3, -1, choices=[], style=wx.LB_MULTIPLE)
        self.button_27 = wx.Button(self.notebook_1_pane_3, -1, u"変更")
        self.label_26 = wx.StaticText(self.notebook_1_pane_3, -1, u"file名変更")
        self.button_s1 = wx.Button(self.notebook_1_pane_3, -1, u"削除")
        self.label_2_copy_1 = wx.StaticText(self.notebook_1_pane_3, -1, u"選択fileを削除")
        self.sizer_4_copy_1_staticbox = wx.StaticBox(self.notebook_1_pane_3, -1, "file(region0)")
        self.button_s2 = wx.Button(self.notebook_1_pane_3, -1, u"配布>>")
        self.button_25 = wx.Button(self.notebook_1_pane_3, -1, u"<<戻す")
        self.button_s3 = wx.Button(self.notebook_1_pane_3, -1, u"配布>>")
        self.button_26 = wx.Button(self.notebook_1_pane_3, -1, u"<<戻す")
        self.label_3_copy_1 = wx.StaticText(self.notebook_1_pane_3, -1, "file")
        self.list_box_s2 = wx.ListBox(self.notebook_1_pane_3, -1, choices=[], style=wx.LB_MULTIPLE)
        self.button_15 = wx.Button(self.notebook_1_pane_3, -1, u"変更")
        self.label_20 = wx.StaticText(self.notebook_1_pane_3, -1, u"file名変更")
        self.button_s4 = wx.Button(self.notebook_1_pane_3, -1, u"削除")
        self.label_4_copy_1 = wx.StaticText(self.notebook_1_pane_3, -1, u"選択fileを削除")
        self.label_5_copy_1 = wx.StaticText(self.notebook_1_pane_3, -1, "region")
        self.list_box_s3 = wx.ListBox(self.notebook_1_pane_3, -1, choices=[])
        self.button_s5 = wx.Button(self.notebook_1_pane_3, -1, u"編集")
        self.label_6_copy_1 = wx.StaticText(self.notebook_1_pane_3, -1, u"file内容確認")
        self.sizer_8_copy_1_staticbox = wx.StaticBox(self.notebook_1_pane_3, -1, u"流体")
        self.label_7_copy_1 = wx.StaticText(self.notebook_1_pane_3, -1, "file")
        self.list_box_s4 = wx.ListBox(self.notebook_1_pane_3, -1, choices=[], style=wx.LB_MULTIPLE)
        self.button_16 = wx.Button(self.notebook_1_pane_3, -1, u"変更")
        self.label_21 = wx.StaticText(self.notebook_1_pane_3, -1, u"file名変更")
        self.button_s6 = wx.Button(self.notebook_1_pane_3, -1, u"削除")
        self.label_8_copy_1 = wx.StaticText(self.notebook_1_pane_3, -1, u"選択fileを削除")
        self.label_9_copy_1 = wx.StaticText(self.notebook_1_pane_3, -1, "region")
        self.list_box_s5 = wx.ListBox(self.notebook_1_pane_3, -1, choices=[])
        self.button_s7 = wx.Button(self.notebook_1_pane_3, -1, u"編集")
        self.label_10_copy_1 = wx.StaticText(self.notebook_1_pane_3, -1, u"file内容確認")
        self.sizer_9_copy_1_staticbox = wx.StaticBox(self.notebook_1_pane_3, -1, u"固体")
        self.notebook_1_pane_4 = wx.Panel(self.notebook_1, -1)
        self.label_12 = wx.StaticText(self.notebook_1_pane_4, -1, u"solidThermophysicalPropertiesの設定")
        self.label_17 = wx.StaticText(self.notebook_1_pane_4, -1, u"DBの場所:")
        self.text_ctrl_2 = wx.TextCtrl(self.notebook_1_pane_4, -1, "")
        self.button_sm0 = wx.Button(self.notebook_1_pane_4, -1, u"参照...")
        self.sizer_26_staticbox = wx.StaticBox(self.notebook_1_pane_4, -1, u"材料DBの場所を設定")
        self.label_11 = wx.StaticText(self.notebook_1_pane_4, -1, u"材料設定方法：・「材料DB」から材料名を選択後、「設定候補」をダブルクリック。\n　　　　　　　　「新材料を設定」ボタンをクリックして設定。\n　　　　　　　・設定fileを準備し、「csvFileで設定」ボタンをクリックして一括設定。")
        self.label_14 = wx.StaticText(self.notebook_1_pane_4, -1, u"材料設定")
        self.list_ctrl_1 = wx.ListCtrl(self.notebook_1_pane_4, -1, style=wx.LC_REPORT | wx.SUNKEN_BORDER)
        self.button_18 = wx.Button(self.notebook_1_pane_4, -1, u"csvFileで設定...")
        self.button_19 = wx.Button(self.notebook_1_pane_4, -1, u"設定をfileに出力")
        self.label_23 = wx.StaticText(self.notebook_1_pane_4, -1, u"各regionの材料設定\nをcsvで一括設定")
        self.sizer_48_staticbox = wx.StaticBox(self.notebook_1_pane_4, -1, u"材料の一括設定")
        self.button_sm1 = wx.Button(self.notebook_1_pane_4, -1, u"編集")
        self.button_sm2 = wx.Button(self.notebook_1_pane_4, -1, u"名称変更")
        self.button_sm3 = wx.Button(self.notebook_1_pane_4, -1, u"DB登録")
        self.label_22 = wx.StaticText(self.notebook_1_pane_4, -1, u"材料名を選択後、\nボタンをクリック")
        self.sizer_49_staticbox = wx.StaticBox(self.notebook_1_pane_4, -1, u"材料DB追加修正")
        self.button_sm4 = wx.Button(self.notebook_1_pane_4, -1, u"新材料を設定")
        self.button_8 = wx.Button(self.notebook_1_pane_4, -1, u"設定候補クリア")
        self.sizer_50_staticbox = wx.StaticBox(self.notebook_1_pane_4, -1, u"材料設定")
        self.bitmap_2 = wx.StaticBitmap(self.notebook_1_pane_4, -1, wx.Bitmap("./icons/backwardArrow.png", wx.BITMAP_TYPE_ANY))
        self.label_13 = wx.StaticText(self.notebook_1_pane_4, -1, u"材料DB")
        self.list_ctrl_2 = wx.ListCtrl(self.notebook_1_pane_4, -1, style=wx.LC_REPORT | wx.SUNKEN_BORDER)
        self.button_sm5 = wx.Button(self.notebook_1_pane_4, -1, u"編集")
        self.button_sm6 = wx.Button(self.notebook_1_pane_4, -1, u"folder開く")
        self.sizer_53_staticbox = wx.StaticBox(self.notebook_1_pane_4, -1, u"材料DB編集")
        self.sizer_22_staticbox = wx.StaticBox(self.notebook_1_pane_4, -1, u"各regionの材料設定")
        self.button_10 = wx.Button(self, -1, u"閉じる")

        self.__set_properties()
        self.__do_layout()

        self.Bind(wx.EVT_LISTBOX_DCLICK, self.onOpenTime, self.list_box_1)
        self.Bind(wx.EVT_BUTTON, self.onRenameTime, self.button_17)
        self.Bind(wx.EVT_BUTTON, self.onDeleteTime, self.button_1)
        self.Bind(wx.EVT_BUTTON, self.onCopyFluidTime, self.button_2)
        self.Bind(wx.EVT_BUTTON, self.onReturnFluidTime, self.button_20)
        self.Bind(wx.EVT_BUTTON, self.onCopySolidTime, self.button_3)
        self.Bind(wx.EVT_BUTTON, self.onReturnSolidTime, self.button_21)
        self.Bind(wx.EVT_LISTBOX_DCLICK, self.onOpenTimeFluid, self.list_box_2)
        self.Bind(wx.EVT_BUTTON, self.onRenameTimeFluid, self.button_11)
        self.Bind(wx.EVT_BUTTON, self.onDeleteTimeFluid, self.button_4)
        self.Bind(wx.EVT_BUTTON, self.onEditTimeFluid, self.button_5)
        self.Bind(wx.EVT_LISTBOX_DCLICK, self.onOpenTimeSolid, self.list_box_4)
        self.Bind(wx.EVT_BUTTON, self.onRenameTimeSolid, self.button_12)
        self.Bind(wx.EVT_BUTTON, self.onDeleteTimeSolid, self.button_6)
        self.Bind(wx.EVT_BUTTON, self.onEditTimeSolid, self.button_7)
        self.Bind(wx.EVT_LISTBOX_DCLICK, self.onOpenConstant, self.list_box_c1)
        self.Bind(wx.EVT_BUTTON, self.onRenameConstant, self.button_24)
        self.Bind(wx.EVT_BUTTON, self.onDeleteConstant, self.button_c1)
        self.Bind(wx.EVT_BUTTON, self.onCopyFluidConstant, self.button_c2)
        self.Bind(wx.EVT_BUTTON, self.onReturnFluidConstant, self.button_22)
        self.Bind(wx.EVT_BUTTON, self.onCopySolidConstant, self.button_c3)
        self.Bind(wx.EVT_BUTTON, self.onReturnSolidConstant, self.button_23)
        self.Bind(wx.EVT_LISTBOX_DCLICK, self.onOpenConstantFluid, self.list_box_c2)
        self.Bind(wx.EVT_BUTTON, self.onRenameConstantFluid, self.button_13)
        self.Bind(wx.EVT_BUTTON, self.onDeleteConstantFluid, self.button_c4)
        self.Bind(wx.EVT_BUTTON, self.onEditConstantFluid, self.button_c5)
        self.Bind(wx.EVT_LISTBOX_DCLICK, self.onOpenConstantSolid, self.list_box_c4)
        self.Bind(wx.EVT_BUTTON, self.onRenameConstantSolid, self.button_14)
        self.Bind(wx.EVT_BUTTON, self.onDeleteConstantSolid, self.button_c6)
        self.Bind(wx.EVT_BUTTON, self.onEditConstantSolid, self.button_c7)
        self.Bind(wx.EVT_LISTBOX_DCLICK, self.onOpenSystem, self.list_box_s1)
        self.Bind(wx.EVT_BUTTON, self.onRenameSystem, self.button_27)
        self.Bind(wx.EVT_BUTTON, self.onDeleteSystem, self.button_s1)
        self.Bind(wx.EVT_BUTTON, self.onCopyFluidSystem, self.button_s2)
        self.Bind(wx.EVT_BUTTON, self.onReturnFluidSystem, self.button_25)
        self.Bind(wx.EVT_BUTTON, self.onCopySolidSystem, self.button_s3)
        self.Bind(wx.EVT_BUTTON, self.onReturnSolidSystem, self.button_26)
        self.Bind(wx.EVT_LISTBOX_DCLICK, self.onOpenSystemFluid, self.list_box_s2)
        self.Bind(wx.EVT_BUTTON, self.onRenameSystemFluid, self.button_15)
        self.Bind(wx.EVT_BUTTON, self.onDeleteSystemFluid, self.button_s4)
        self.Bind(wx.EVT_BUTTON, self.onEditSystemFluid, self.button_s5)
        self.Bind(wx.EVT_LISTBOX_DCLICK, self.onOpenSystemSolid, self.list_box_s4)
        self.Bind(wx.EVT_BUTTON, self.onRenameSystemSolid, self.button_16)
        self.Bind(wx.EVT_BUTTON, self.onDeleteSystemSolid, self.button_s6)
        self.Bind(wx.EVT_BUTTON, self.onEditSystemSolid, self.button_s7)
        self.Bind(wx.EVT_BUTTON, self.onSetPhysicalDir, self.button_sm0)
        self.Bind(wx.EVT_BUTTON, self.onSetCSVFile, self.button_18)
        self.Bind(wx.EVT_BUTTON, self.onOutputCSVFile, self.button_19)
        self.Bind(wx.EVT_BUTTON, self.onEditRegionMaterial, self.button_sm1)
        self.Bind(wx.EVT_BUTTON, self.onRenameRegionMaterial, self.button_sm2)
        self.Bind(wx.EVT_BUTTON, self.onSaveMaterialDB, self.button_sm3)
        self.Bind(wx.EVT_BUTTON, self.onSetMaterialToRegion, self.button_sm4)
        self.Bind(wx.EVT_BUTTON, self.onClearMatReq, self.button_8)
        self.Bind(wx.EVT_BUTTON, self.onEditMaterialDB, self.button_sm5)
        self.Bind(wx.EVT_BUTTON, self.onOpenMaterialDBfolder, self.button_sm6)
        self.Bind(wx.EVT_NOTEBOOK_PAGE_CHANGED, self.onReloadData, self.notebook_1)
        self.Bind(wx.EVT_BUTTON, self.onClose, self.button_10)
        # end wxGlade

        self.list_ctrl_1.Bind(wx.EVT_LEFT_DCLICK, self.onCheckInListDclick)
        self.list_ctrl_2.Bind(wx.EVT_LEFT_DCLICK, self.onOpenMaterialDB)

        os.chdir(savePath)
        #regionがあるかどうかを確認する
        self.checkRegions()
        #dataをlistBoxにセット
        self.setFileNameMaterialToListBox()
        #setPage
        self.notebook_1.SetSelection(1)

    def __set_properties(self):
        # begin wxGlade: MyFrame.__set_properties
        self.SetTitle(u"regionのファイル操作")
        self.list_box_1.SetMinSize((220, 300))
        self.button_17.SetMinSize((40, 25))
        self.button_1.SetMinSize((40, 25))
        self.button_2.SetMinSize((55, 48))
        self.button_20.SetMinSize((55, 30))
        self.button_3.SetMinSize((55, 48))
        self.button_21.SetMinSize((55, 30))
        self.list_box_2.SetMinSize((150, 100))
        self.button_11.SetMinSize((40, 25))
        self.button_4.SetMinSize((40, 25))
        self.list_box_3.SetMinSize((150, 100))
        self.button_5.SetMinSize((40, 25))
        self.list_box_4.SetMinSize((150, 100))
        self.button_12.SetMinSize((40, 25))
        self.button_6.SetMinSize((40, 25))
        self.list_box_5.SetMinSize((150, 100))
        self.button_7.SetMinSize((40, 25))
        self.list_box_c1.SetMinSize((220, 300))
        self.button_24.SetMinSize((40, 25))
        self.button_c1.SetMinSize((40, 25))
        self.button_c2.SetMinSize((55, 48))
        self.button_22.SetMinSize((55, 30))
        self.button_c3.SetMinSize((55, 48))
        self.button_23.SetMinSize((55, 30))
        self.list_box_c2.SetMinSize((150, 100))
        self.button_13.SetMinSize((40, 25))
        self.button_c4.SetMinSize((40, 25))
        self.list_box_c3.SetMinSize((150, 100))
        self.button_c5.SetMinSize((40, 25))
        self.list_box_c4.SetMinSize((150, 100))
        self.button_14.SetMinSize((40, 25))
        self.button_c6.SetMinSize((40, 25))
        self.list_box_c5.SetMinSize((150, 100))
        self.button_c7.SetMinSize((40, 25))
        self.list_box_s1.SetMinSize((220, 300))
        self.button_27.SetMinSize((40, 25))
        self.button_s1.SetMinSize((40, 25))
        self.button_s2.SetMinSize((55, 48))
        self.button_25.SetMinSize((55, 30))
        self.button_s3.SetMinSize((55, 48))
        self.button_26.SetMinSize((55, 30))
        self.list_box_s2.SetMinSize((150, 100))
        self.button_15.SetMinSize((40, 25))
        self.button_s4.SetMinSize((40, 25))
        self.list_box_s3.SetMinSize((150, 100))
        self.button_s5.SetMinSize((40, 25))
        self.list_box_s4.SetMinSize((150, 100))
        self.button_16.SetMinSize((40, 25))
        self.button_s6.SetMinSize((40, 25))
        self.list_box_s5.SetMinSize((150, 100))
        self.button_s7.SetMinSize((40, 25))
        self.button_sm0.SetMinSize((60, 30))
        self.list_ctrl_1.SetMinSize((330, 130))
        self.button_18.SetMinSize((122, 25))
        self.button_19.SetMinSize((122, 25))
        self.button_sm1.SetMinSize((120, 25))
        self.button_sm2.SetMinSize((120, 25))
        self.button_sm3.SetMinSize((120, 25))
        self.button_sm4.SetMinSize((120, 25))
        self.button_8.SetMinSize((120, 25))
        self.button_sm5.SetMinSize((98, 25))
        self.button_sm6.SetMinSize((98, 25))
        # end wxGlade

        #listCtrlの設定
        self.list_ctrl_1.InsertColumn(0, u"region", wx.LIST_FORMAT_LEFT, 140)
        self.list_ctrl_1.InsertColumn(1, u"現在の設定", wx.LIST_FORMAT_LEFT, 135)
        self.list_ctrl_1.InsertColumn(2, u"設定候補", wx.LIST_FORMAT_LEFT, 135)
        i = 0
        for name in solidRegions:
            self.list_ctrl_1.InsertStringItem(i, name)
            self.list_ctrl_1.SetStringItem(i, 1, constantSolidPhysical[i])
            self.list_ctrl_1.SetStringItem(i, 2, constantSolidPhysicalReq[i])
            i += 1

        self.list_ctrl_2.InsertColumn(0, u"material", wx.LIST_FORMAT_LEFT, 160)
        i = 0
        for name in solidPhysicalDB:
            self.list_ctrl_2.InsertStringItem(i, name)
            i += 1

    def __do_layout(self):
        # begin wxGlade: MyFrame.__do_layout
        sizer_1 = wx.BoxSizer(wx.VERTICAL)
        sizer_24 = wx.BoxSizer(wx.VERTICAL)
        sizer_25 = wx.BoxSizer(wx.HORIZONTAL)
        sizer_21 = wx.BoxSizer(wx.VERTICAL)
        self.sizer_22_staticbox.Lower()
        sizer_22 = wx.StaticBoxSizer(self.sizer_22_staticbox, wx.HORIZONTAL)
        sizer_46 = wx.BoxSizer(wx.VERTICAL)
        sizer_45 = wx.BoxSizer(wx.VERTICAL)
        sizer_51 = wx.BoxSizer(wx.HORIZONTAL)
        self.sizer_53_staticbox.Lower()
        sizer_53 = wx.StaticBoxSizer(self.sizer_53_staticbox, wx.VERTICAL)
        sizer_52 = wx.BoxSizer(wx.VERTICAL)
        sizer_44 = wx.BoxSizer(wx.VERTICAL)
        sizer_23 = wx.BoxSizer(wx.VERTICAL)
        sizer_47 = wx.BoxSizer(wx.HORIZONTAL)
        self.sizer_50_staticbox.Lower()
        sizer_50 = wx.StaticBoxSizer(self.sizer_50_staticbox, wx.VERTICAL)
        self.sizer_49_staticbox.Lower()
        sizer_49 = wx.StaticBoxSizer(self.sizer_49_staticbox, wx.VERTICAL)
        self.sizer_48_staticbox.Lower()
        sizer_48 = wx.StaticBoxSizer(self.sizer_48_staticbox, wx.VERTICAL)
        sizer_32 = wx.BoxSizer(wx.HORIZONTAL)
        sizer_18 = wx.BoxSizer(wx.HORIZONTAL)
        sizer_19 = wx.BoxSizer(wx.VERTICAL)
        sizer_20 = wx.BoxSizer(wx.HORIZONTAL)
        self.sizer_26_staticbox.Lower()
        sizer_26 = wx.StaticBoxSizer(self.sizer_26_staticbox, wx.HORIZONTAL)
        sizer_3_copy_1 = wx.BoxSizer(wx.HORIZONTAL)
        sizer_7_copy_1 = wx.BoxSizer(wx.VERTICAL)
        self.sizer_9_copy_1_staticbox.Lower()
        sizer_9_copy_1 = wx.StaticBoxSizer(self.sizer_9_copy_1_staticbox, wx.HORIZONTAL)
        sizer_16_copy_1 = wx.BoxSizer(wx.VERTICAL)
        sizer_17_copy_1 = wx.BoxSizer(wx.HORIZONTAL)
        sizer_14_copy_1 = wx.BoxSizer(wx.VERTICAL)
        sizer_34 = wx.BoxSizer(wx.HORIZONTAL)
        sizer_31 = wx.BoxSizer(wx.HORIZONTAL)
        self.sizer_8_copy_1_staticbox.Lower()
        sizer_8_copy_1 = wx.StaticBoxSizer(self.sizer_8_copy_1_staticbox, wx.HORIZONTAL)
        sizer_12_copy_1 = wx.BoxSizer(wx.VERTICAL)
        sizer_13_copy_1 = wx.BoxSizer(wx.HORIZONTAL)
        sizer_10_copy_1 = wx.BoxSizer(wx.VERTICAL)
        sizer_33 = wx.BoxSizer(wx.HORIZONTAL)
        sizer_30 = wx.BoxSizer(wx.HORIZONTAL)
        sizer_6_copy_1 = wx.BoxSizer(wx.VERTICAL)
        self.sizer_4_copy_1_staticbox.Lower()
        sizer_4_copy_1 = wx.StaticBoxSizer(self.sizer_4_copy_1_staticbox, wx.VERTICAL)
        sizer_5_copy_1 = wx.BoxSizer(wx.HORIZONTAL)
        sizer_55 = wx.BoxSizer(wx.HORIZONTAL)
        sizer_3_copy = wx.BoxSizer(wx.HORIZONTAL)
        sizer_7_copy = wx.BoxSizer(wx.VERTICAL)
        self.sizer_39_staticbox.Lower()
        sizer_39 = wx.StaticBoxSizer(self.sizer_39_staticbox, wx.HORIZONTAL)
        sizer_41 = wx.BoxSizer(wx.VERTICAL)
        sizer_43 = wx.BoxSizer(wx.HORIZONTAL)
        sizer_40 = wx.BoxSizer(wx.VERTICAL)
        sizer_36 = wx.BoxSizer(wx.HORIZONTAL)
        sizer_29 = wx.BoxSizer(wx.HORIZONTAL)
        self.sizer_8_copy_staticbox.Lower()
        sizer_8_copy = wx.StaticBoxSizer(self.sizer_8_copy_staticbox, wx.HORIZONTAL)
        sizer_12_copy = wx.BoxSizer(wx.VERTICAL)
        sizer_13_copy = wx.BoxSizer(wx.HORIZONTAL)
        sizer_10_copy = wx.BoxSizer(wx.VERTICAL)
        sizer_35 = wx.BoxSizer(wx.HORIZONTAL)
        sizer_28 = wx.BoxSizer(wx.HORIZONTAL)
        sizer_6_copy = wx.BoxSizer(wx.VERTICAL)
        self.sizer_4_copy_staticbox.Lower()
        sizer_4_copy = wx.StaticBoxSizer(self.sizer_4_copy_staticbox, wx.VERTICAL)
        sizer_5_copy = wx.BoxSizer(wx.HORIZONTAL)
        sizer_54 = wx.BoxSizer(wx.HORIZONTAL)
        sizer_3 = wx.BoxSizer(wx.HORIZONTAL)
        sizer_7 = wx.BoxSizer(wx.VERTICAL)
        self.sizer_9_staticbox.Lower()
        sizer_9 = wx.StaticBoxSizer(self.sizer_9_staticbox, wx.HORIZONTAL)
        sizer_16 = wx.BoxSizer(wx.VERTICAL)
        sizer_17 = wx.BoxSizer(wx.HORIZONTAL)
        sizer_14 = wx.BoxSizer(wx.VERTICAL)
        sizer_38 = wx.BoxSizer(wx.HORIZONTAL)
        sizer_27 = wx.BoxSizer(wx.HORIZONTAL)
        self.sizer_8_staticbox.Lower()
        sizer_8 = wx.StaticBoxSizer(self.sizer_8_staticbox, wx.HORIZONTAL)
        sizer_12 = wx.BoxSizer(wx.VERTICAL)
        sizer_13 = wx.BoxSizer(wx.HORIZONTAL)
        sizer_10 = wx.BoxSizer(wx.VERTICAL)
        sizer_37 = wx.BoxSizer(wx.HORIZONTAL)
        sizer_2 = wx.BoxSizer(wx.HORIZONTAL)
        sizer_6 = wx.BoxSizer(wx.VERTICAL)
        self.sizer_4_staticbox.Lower()
        sizer_4 = wx.StaticBoxSizer(self.sizer_4_staticbox, wx.VERTICAL)
        sizer_5 = wx.BoxSizer(wx.HORIZONTAL)
        sizer_42 = wx.BoxSizer(wx.HORIZONTAL)
        sizer_1.Add(self.label_1, 0, wx.LEFT | wx.RIGHT | wx.TOP | wx.ALIGN_CENTER_HORIZONTAL, 10)
        sizer_4.Add((20, 10), 0, 0, 0)
        sizer_4.Add(self.list_box_1, 1, wx.LEFT | wx.RIGHT | wx.TOP | wx.EXPAND, 5)
        sizer_42.Add(self.button_17, 0, wx.LEFT, 5)
        sizer_42.Add(self.label_24, 0, wx.ALIGN_CENTER_VERTICAL, 0)
        sizer_4.Add(sizer_42, 0, wx.EXPAND, 0)
        sizer_5.Add(self.button_1, 0, wx.LEFT, 5)
        sizer_5.Add(self.label_2, 0, wx.ALIGN_CENTER_VERTICAL, 0)
        sizer_4.Add(sizer_5, 0, wx.EXPAND, 0)
        sizer_3.Add(sizer_4, 0, wx.ALL | wx.EXPAND, 5)
        sizer_6.Add((20, 50), 0, 0, 0)
        sizer_6.Add(self.button_2, 0, 0, 0)
        sizer_6.Add(self.button_20, 0, wx.TOP, 0)
        sizer_6.Add((20, 155), 0, 0, 0)
        sizer_6.Add(self.button_3, 0, 0, 0)
        sizer_6.Add(self.button_21, 0, 0, 0)
        sizer_3.Add(sizer_6, 0, wx.EXPAND, 0)
        sizer_10.Add(self.label_3, 0, wx.LEFT, 5)
        sizer_10.Add(self.list_box_2, 1, wx.LEFT | wx.RIGHT | wx.EXPAND, 5)
        sizer_2.Add(self.button_11, 0, wx.LEFT | wx.ALIGN_CENTER_VERTICAL, 5)
        sizer_2.Add(self.label_15, 0, wx.ALIGN_CENTER_VERTICAL, 0)
        sizer_10.Add(sizer_2, 0, wx.EXPAND, 0)
        sizer_37.Add(self.button_4, 0, wx.LEFT | wx.ALIGN_CENTER_VERTICAL, 5)
        sizer_37.Add(self.label_4, 0, wx.ALIGN_CENTER_VERTICAL, 0)
        sizer_10.Add(sizer_37, 0, wx.EXPAND, 0)
        sizer_8.Add(sizer_10, 1, wx.EXPAND, 0)
        sizer_12.Add(self.label_5, 0, wx.LEFT, 5)
        sizer_12.Add(self.list_box_3, 1, wx.LEFT | wx.RIGHT | wx.EXPAND, 5)
        sizer_13.Add(self.button_5, 0, wx.LEFT, 5)
        sizer_13.Add(self.label_6, 0, wx.ALIGN_CENTER_VERTICAL, 0)
        sizer_12.Add(sizer_13, 0, wx.EXPAND, 0)
        sizer_12.Add((20, 25), 0, 0, 0)
        sizer_8.Add(sizer_12, 1, wx.EXPAND, 0)
        sizer_7.Add(sizer_8, 1, wx.ALL | wx.EXPAND, 5)
        sizer_14.Add(self.label_7, 0, wx.LEFT, 5)
        sizer_14.Add(self.list_box_4, 1, wx.LEFT | wx.RIGHT | wx.EXPAND, 5)
        sizer_27.Add(self.button_12, 0, wx.LEFT, 5)
        sizer_27.Add(self.label_16, 0, wx.ALIGN_CENTER_VERTICAL, 0)
        sizer_14.Add(sizer_27, 0, wx.EXPAND, 0)
        sizer_38.Add(self.button_6, 0, wx.LEFT, 5)
        sizer_38.Add(self.label_8, 0, wx.ALIGN_CENTER_VERTICAL, 0)
        sizer_14.Add(sizer_38, 0, wx.EXPAND, 0)
        sizer_9.Add(sizer_14, 1, wx.EXPAND, 0)
        sizer_16.Add(self.label_9, 0, wx.LEFT, 5)
        sizer_16.Add(self.list_box_5, 1, wx.LEFT | wx.RIGHT | wx.EXPAND, 5)
        sizer_17.Add(self.button_7, 0, wx.LEFT, 5)
        sizer_17.Add(self.label_10, 0, wx.ALIGN_CENTER_VERTICAL, 0)
        sizer_16.Add(sizer_17, 0, wx.EXPAND, 0)
        sizer_16.Add((20, 25), 0, 0, 0)
        sizer_9.Add(sizer_16, 1, wx.EXPAND, 0)
        sizer_7.Add(sizer_9, 1, wx.ALL | wx.EXPAND, 5)
        sizer_3.Add(sizer_7, 1, wx.EXPAND, 0)
        self.notebook_1_pane_1.SetSizer(sizer_3)
        sizer_4_copy.Add((20, 10), 0, 0, 0)
        sizer_4_copy.Add(self.list_box_c1, 1, wx.LEFT | wx.RIGHT | wx.TOP | wx.EXPAND, 5)
        sizer_54.Add(self.button_24, 0, wx.LEFT, 5)
        sizer_54.Add(self.label_25, 0, wx.ALIGN_CENTER_VERTICAL, 0)
        sizer_4_copy.Add(sizer_54, 0, wx.EXPAND, 0)
        sizer_5_copy.Add(self.button_c1, 0, wx.LEFT, 5)
        sizer_5_copy.Add(self.label_2_copy, 0, wx.ALIGN_CENTER_VERTICAL, 0)
        sizer_4_copy.Add(sizer_5_copy, 0, wx.EXPAND, 0)
        sizer_3_copy.Add(sizer_4_copy, 0, wx.ALL | wx.EXPAND, 5)
        sizer_6_copy.Add((20, 50), 0, 0, 0)
        sizer_6_copy.Add(self.button_c2, 0, 0, 0)
        sizer_6_copy.Add(self.button_22, 0, 0, 0)
        sizer_6_copy.Add((20, 155), 0, 0, 0)
        sizer_6_copy.Add(self.button_c3, 0, 0, 0)
        sizer_6_copy.Add(self.button_23, 0, 0, 0)
        sizer_3_copy.Add(sizer_6_copy, 0, wx.EXPAND, 0)
        sizer_10_copy.Add(self.label_3_copy, 0, wx.LEFT, 5)
        sizer_10_copy.Add(self.list_box_c2, 1, wx.LEFT | wx.RIGHT | wx.EXPAND, 5)
        sizer_28.Add(self.button_13, 0, wx.LEFT, 5)
        sizer_28.Add(self.label_18, 0, wx.ALIGN_CENTER_VERTICAL, 0)
        sizer_10_copy.Add(sizer_28, 0, wx.EXPAND, 0)
        sizer_35.Add(self.button_c4, 0, wx.LEFT, 5)
        sizer_35.Add(self.label_4_copy, 0, wx.ALIGN_CENTER_VERTICAL, 0)
        sizer_10_copy.Add(sizer_35, 0, wx.EXPAND, 0)
        sizer_8_copy.Add(sizer_10_copy, 1, wx.EXPAND, 0)
        sizer_12_copy.Add(self.label_5_copy, 0, wx.LEFT, 5)
        sizer_12_copy.Add(self.list_box_c3, 1, wx.LEFT | wx.RIGHT | wx.EXPAND, 5)
        sizer_13_copy.Add(self.button_c5, 0, wx.LEFT, 5)
        sizer_13_copy.Add(self.label_6_copy, 0, wx.ALIGN_CENTER_VERTICAL, 0)
        sizer_12_copy.Add(sizer_13_copy, 0, wx.EXPAND, 0)
        sizer_12_copy.Add((20, 25), 0, 0, 0)
        sizer_8_copy.Add(sizer_12_copy, 1, wx.EXPAND, 0)
        sizer_7_copy.Add(sizer_8_copy, 1, wx.ALL | wx.EXPAND, 5)
        sizer_40.Add(self.label_7_copy, 0, wx.LEFT, 5)
        sizer_40.Add(self.list_box_c4, 1, wx.LEFT | wx.RIGHT | wx.EXPAND, 5)
        sizer_29.Add(self.button_14, 0, wx.LEFT, 5)
        sizer_29.Add(self.label_19, 0, wx.ALIGN_CENTER_VERTICAL, 0)
        sizer_40.Add(sizer_29, 0, wx.EXPAND, 0)
        sizer_36.Add(self.button_c6, 0, wx.LEFT, 5)
        sizer_36.Add(self.label_8_copy, 0, wx.ALIGN_CENTER_VERTICAL, 0)
        sizer_40.Add(sizer_36, 0, wx.EXPAND, 0)
        sizer_39.Add(sizer_40, 1, wx.EXPAND, 0)
        sizer_41.Add(self.label_9_copy, 0, wx.LEFT, 5)
        sizer_41.Add(self.list_box_c5, 1, wx.LEFT | wx.RIGHT | wx.EXPAND, 5)
        sizer_43.Add(self.button_c7, 0, wx.LEFT, 5)
        sizer_43.Add(self.label_10_copy, 0, wx.ALIGN_CENTER_VERTICAL, 0)
        sizer_41.Add(sizer_43, 0, wx.EXPAND, 0)
        sizer_41.Add((20, 25), 0, 0, 0)
        sizer_39.Add(sizer_41, 1, wx.EXPAND, 0)
        sizer_7_copy.Add(sizer_39, 1, wx.ALL | wx.EXPAND, 5)
        sizer_3_copy.Add(sizer_7_copy, 1, wx.EXPAND, 0)
        self.notebook_1_pane_2.SetSizer(sizer_3_copy)
        sizer_4_copy_1.Add((20, 10), 0, 0, 0)
        sizer_4_copy_1.Add(self.list_box_s1, 1, wx.LEFT | wx.RIGHT | wx.TOP | wx.EXPAND, 5)
        sizer_55.Add(self.button_27, 0, wx.LEFT, 5)
        sizer_55.Add(self.label_26, 0, wx.ALIGN_CENTER_VERTICAL, 0)
        sizer_4_copy_1.Add(sizer_55, 0, wx.EXPAND, 0)
        sizer_5_copy_1.Add(self.button_s1, 0, wx.LEFT, 5)
        sizer_5_copy_1.Add(self.label_2_copy_1, 0, wx.ALIGN_CENTER_VERTICAL, 0)
        sizer_4_copy_1.Add(sizer_5_copy_1, 0, wx.EXPAND, 0)
        sizer_3_copy_1.Add(sizer_4_copy_1, 0, wx.ALL | wx.EXPAND, 5)
        sizer_6_copy_1.Add((20, 50), 0, 0, 0)
        sizer_6_copy_1.Add(self.button_s2, 0, 0, 0)
        sizer_6_copy_1.Add(self.button_25, 0, 0, 0)
        sizer_6_copy_1.Add((20, 155), 0, 0, 0)
        sizer_6_copy_1.Add(self.button_s3, 0, 0, 0)
        sizer_6_copy_1.Add(self.button_26, 0, 0, 0)
        sizer_3_copy_1.Add(sizer_6_copy_1, 0, wx.EXPAND, 0)
        sizer_10_copy_1.Add(self.label_3_copy_1, 0, wx.LEFT, 5)
        sizer_10_copy_1.Add(self.list_box_s2, 1, wx.LEFT | wx.RIGHT | wx.EXPAND, 5)
        sizer_30.Add(self.button_15, 0, wx.LEFT, 5)
        sizer_30.Add(self.label_20, 0, wx.ALIGN_CENTER_VERTICAL, 0)
        sizer_10_copy_1.Add(sizer_30, 0, wx.EXPAND, 0)
        sizer_33.Add(self.button_s4, 0, wx.LEFT, 5)
        sizer_33.Add(self.label_4_copy_1, 0, wx.ALIGN_CENTER_VERTICAL, 0)
        sizer_10_copy_1.Add(sizer_33, 0, wx.EXPAND, 0)
        sizer_8_copy_1.Add(sizer_10_copy_1, 1, wx.EXPAND, 0)
        sizer_12_copy_1.Add(self.label_5_copy_1, 0, wx.LEFT, 5)
        sizer_12_copy_1.Add(self.list_box_s3, 1, wx.LEFT | wx.RIGHT | wx.EXPAND, 5)
        sizer_13_copy_1.Add(self.button_s5, 0, wx.LEFT, 5)
        sizer_13_copy_1.Add(self.label_6_copy_1, 0, wx.ALIGN_CENTER_VERTICAL, 0)
        sizer_12_copy_1.Add(sizer_13_copy_1, 0, wx.EXPAND, 0)
        sizer_12_copy_1.Add((20, 25), 0, 0, 0)
        sizer_8_copy_1.Add(sizer_12_copy_1, 1, wx.EXPAND, 0)
        sizer_7_copy_1.Add(sizer_8_copy_1, 1, wx.ALL | wx.EXPAND, 5)
        sizer_14_copy_1.Add(self.label_7_copy_1, 0, wx.LEFT, 5)
        sizer_14_copy_1.Add(self.list_box_s4, 1, wx.LEFT | wx.RIGHT | wx.EXPAND, 5)
        sizer_31.Add(self.button_16, 0, wx.LEFT, 5)
        sizer_31.Add(self.label_21, 0, wx.ALIGN_CENTER_VERTICAL, 0)
        sizer_14_copy_1.Add(sizer_31, 0, wx.EXPAND, 0)
        sizer_34.Add(self.button_s6, 0, wx.LEFT, 5)
        sizer_34.Add(self.label_8_copy_1, 0, wx.ALIGN_CENTER_VERTICAL, 0)
        sizer_14_copy_1.Add(sizer_34, 0, wx.EXPAND, 0)
        sizer_9_copy_1.Add(sizer_14_copy_1, 1, wx.EXPAND, 0)
        sizer_16_copy_1.Add(self.label_9_copy_1, 0, wx.LEFT, 5)
        sizer_16_copy_1.Add(self.list_box_s5, 1, wx.LEFT | wx.RIGHT | wx.EXPAND, 5)
        sizer_17_copy_1.Add(self.button_s7, 0, wx.LEFT, 5)
        sizer_17_copy_1.Add(self.label_10_copy_1, 0, wx.ALIGN_CENTER_VERTICAL, 0)
        sizer_16_copy_1.Add(sizer_17_copy_1, 0, wx.EXPAND, 0)
        sizer_16_copy_1.Add((20, 25), 0, 0, 0)
        sizer_9_copy_1.Add(sizer_16_copy_1, 1, wx.EXPAND, 0)
        sizer_7_copy_1.Add(sizer_9_copy_1, 1, wx.ALL | wx.EXPAND, 5)
        sizer_3_copy_1.Add(sizer_7_copy_1, 1, wx.EXPAND, 0)
        self.notebook_1_pane_3.SetSizer(sizer_3_copy_1)
        sizer_21.Add(self.label_12, 0, wx.ALL | wx.ALIGN_CENTER_HORIZONTAL, 10)
        sizer_26.Add(self.label_17, 0, wx.LEFT | wx.ALIGN_CENTER_VERTICAL, 10)
        sizer_26.Add(self.text_ctrl_2, 1, 0, 0)
        sizer_26.Add(self.button_sm0, 0, wx.RIGHT, 10)
        sizer_21.Add(sizer_26, 0, wx.LEFT | wx.RIGHT | wx.BOTTOM | wx.EXPAND, 10)
        sizer_20.Add(self.label_11, 0, 0, 0)
        sizer_19.Add(sizer_20, 1, wx.ALIGN_RIGHT, 0)
        sizer_18.Add(sizer_19, 1, wx.EXPAND, 0)
        sizer_21.Add(sizer_18, 0, wx.EXPAND, 0)
        sizer_22.Add((20, 20), 0, 0, 0)
        sizer_32.Add(self.label_14, 0, wx.ALIGN_BOTTOM, 0)
        sizer_23.Add(sizer_32, 0, wx.EXPAND, 0)
        sizer_23.Add(self.list_ctrl_1, 1, wx.EXPAND, 0)
        sizer_48.Add(self.button_18, 0, wx.ALIGN_CENTER_HORIZONTAL, 0)
        sizer_48.Add(self.button_19, 0, wx.ALIGN_CENTER_HORIZONTAL, 0)
        sizer_48.Add(self.label_23, 0, 0, 0)
        sizer_47.Add(sizer_48, 1, wx.ALL | wx.EXPAND, 3)
        sizer_49.Add(self.button_sm1, 0, wx.ALIGN_CENTER_HORIZONTAL, 0)
        sizer_49.Add(self.button_sm2, 0, wx.ALIGN_CENTER_HORIZONTAL, 0)
        sizer_49.Add(self.button_sm3, 0, wx.ALIGN_CENTER_HORIZONTAL, 0)
        sizer_49.Add(self.label_22, 0, 0, 0)
        sizer_47.Add(sizer_49, 1, wx.ALL | wx.EXPAND, 3)
        sizer_50.Add(self.button_sm4, 0, wx.ALIGN_CENTER_HORIZONTAL, 0)
        sizer_50.Add(self.button_8, 0, wx.ALIGN_CENTER_HORIZONTAL, 0)
        sizer_47.Add(sizer_50, 1, wx.ALL | wx.EXPAND, 3)
        sizer_23.Add(sizer_47, 0, wx.EXPAND, 0)
        sizer_22.Add(sizer_23, 2, wx.EXPAND, 0)
        sizer_44.Add((50, 20), 0, 0, 0)
        sizer_44.Add(self.bitmap_2, 0, wx.TOP | wx.ALIGN_CENTER_HORIZONTAL, 70)
        sizer_22.Add(sizer_44, 0, wx.EXPAND, 0)
        sizer_45.Add(self.label_13, 0, wx.TOP, 5)
        sizer_45.Add(self.list_ctrl_2, 1, wx.EXPAND, 0)
        sizer_52.Add((20, 140), 0, 0, 0)
        sizer_51.Add(sizer_52, 0, wx.EXPAND, 0)
        sizer_53.Add(self.button_sm5, 0, wx.ALIGN_CENTER_HORIZONTAL, 0)
        sizer_53.Add(self.button_sm6, 0, wx.ALIGN_CENTER_HORIZONTAL, 0)
        sizer_51.Add(sizer_53, 1, wx.ALL | wx.EXPAND, 3)
        sizer_51.Add((20, 20), 0, 0, 0)
        sizer_45.Add(sizer_51, 0, wx.EXPAND, 0)
        sizer_22.Add(sizer_45, 1, wx.EXPAND, 0)
        sizer_46.Add((20, 20), 0, 0, 0)
        sizer_22.Add(sizer_46, 0, wx.EXPAND, 0)
        sizer_21.Add(sizer_22, 1, wx.LEFT | wx.RIGHT | wx.BOTTOM | wx.EXPAND, 10)
        self.notebook_1_pane_4.SetSizer(sizer_21)
        self.notebook_1.AddPage(self.notebook_1_pane_1, "time")
        self.notebook_1.AddPage(self.notebook_1_pane_2, "constant")
        self.notebook_1.AddPage(self.notebook_1_pane_3, "system")
        self.notebook_1.AddPage(self.notebook_1_pane_4, u"固体の材料設定")
        sizer_1.Add(self.notebook_1, 1, wx.LEFT | wx.RIGHT | wx.BOTTOM | wx.EXPAND, 10)
        sizer_25.Add(self.button_10, 0, wx.LEFT | wx.RIGHT | wx.BOTTOM, 10)
        sizer_24.Add(sizer_25, 1, wx.ALIGN_RIGHT, 0)
        sizer_1.Add(sizer_24, 0, wx.EXPAND, 0)
        self.SetSizer(sizer_1)
        sizer_1.Fit(self)
        self.Layout()
        # end wxGlade

        #page 0 のtitleを書き換え
        self.notebook_1.SetPageText(0 , iniTime)
        
    #------------Dclick時------------------
    def onCheckInListDclick(self, event):
        self.checkInListDclick(event)

    #------------pageChangeed--------------
    def onReloadData(self, event): # wxGlade: MyFrame.<event_handler>
        self.reloadData(event)

    #------------time--------------
    #time削除    
    def onDeleteTime(self, event):  # wxGlade: MyFrame.<event_handler>
        fileBox = self.list_box_1
        self.deleteDirectFiles(fileBox, iniTime)

    #timeRename
    def onRenameTime(self, event):  # wxGlade: MyFrame.<event_handler>
        fileBox = self.list_box_1
        self.renameDirectFile(fileBox, iniTime)

    #timeFluidコピー
    def onCopyFluidTime(self, event):  # wxGlade: MyFrame.<event_handler>
        fileBox = self.list_box_1
        self.copyFiles(fileBox, "fluid", iniTime)

    #timeSolidコピー
    def onCopySolidTime(self, event):  # wxGlade: MyFrame.<event_handler>
        fileBox = self.list_box_1
        self.copyFiles(fileBox, "solid", iniTime)

    #timeFluid戻す
    def onReturnFluidTime(self, event):  # wxGlade: MyFrame.<event_handler>
        fileBox = self.list_box_2
        regionBox = self.list_box_3
        self.returnFiles(fileBox, regionBox, iniTime)

    #timeSolid戻す
    def onReturnSolidTime(self, event):  # wxGlade: MyFrame.<event_handler>
        fileBox = self.list_box_4
        regionBox = self.list_box_5
        self.returnFiles(fileBox, regionBox, iniTime)

    #timeFluid削除
    def onDeleteTimeFluid(self, event):  # wxGlade: MyFrame.<event_handler>
        fileBox = self.list_box_2
        self.deleteFiles(fileBox, "fluid", iniTime)

    #timeFluid編集
    def onEditTimeFluid(self, event):  # wxGlade: MyFrame.<event_handler>
        fileBox = self.list_box_2
        regionBox = self.list_box_3
        self.editFiles(fileBox, regionBox, iniTime)

    #timeSolid削除
    def onDeleteTimeSolid(self, event):  # wxGlade: MyFrame.<event_handler>
        fileBox = self.list_box_4
        self.deleteFiles(fileBox, "solid", iniTime)

    #timeSolid編集
    def onEditTimeSolid(self, event):  # wxGlade: MyFrame.<event_handler>
        fileBox = self.list_box_4
        regionBox = self.list_box_5
        self.editFiles(fileBox, regionBox, iniTime)

    #------------constant--------------
    #constant削除
    def onDeleteConstant(self, event):  # wxGlade: MyFrame.<event_handler>
        fileBox = self.list_box_c1
        self.deleteDirectFiles(fileBox, "constant")

    #constantRename
    def onRenameConstant(self, event):  # wxGlade: MyFrame.<event_handler>
        fileBox = self.list_box_c1
        self.renameDirectFile(fileBox, "constant")

    #constantFluidコピー
    def onCopyFluidConstant(self, event):  # wxGlade: MyFrame.<event_handler>
        fileBox = self.list_box_c1
        self.copyFiles(fileBox, "fluid", "constant")

    #constantSolidコピー
    def onCopySolidConstant(self, event):  # wxGlade: MyFrame.<event_handler>
        fileBox = self.list_box_c1
        self.copyFiles(fileBox, "solid", "constant")

    #constantFluid戻す
    def onReturnFluidConstant(self, event):  # wxGlade: MyFrame.<event_handler>
        fileBox = self.list_box_c2
        regionBox = self.list_box_c3
        self.returnFiles(fileBox, regionBox, "constant")

    #constantSolid戻す
    def onReturnSolidConstant(self, event):  # wxGlade: MyFrame.<event_handler>
        fileBox = self.list_box_c4
        regionBox = self.list_box_c5
        self.returnFiles(fileBox, regionBox, "constant")

    #constantFluid削除
    def onDeleteConstantFluid(self, event):  # wxGlade: MyFrame.<event_handler>
        fileBox = self.list_box_c2
        self.deleteFiles(fileBox, "fluid", "constant")

    #constantFluid編集
    def onEditConstantFluid(self, event):  # wxGlade: MyFrame.<event_handler>
        fileBox = self.list_box_c2
        regionBox = self.list_box_c3
        self.editFiles(fileBox, regionBox, "constant")

    #constantSolid削除
    def onDeleteConstantSolid(self, event):  # wxGlade: MyFrame.<event_handler>
        fileBox = self.list_box_c4
        self.deleteFiles(fileBox, "solid", "constant")

    #constantSolid編集
    def onEditConstantSolid(self, event):  # wxGlade: MyFrame.<event_handler>
        fileBox = self.list_box_c4
        regionBox = self.list_box_c5
        self.editFiles(fileBox, regionBox, "constant")

    #constant参照
    def onSetPhysicalDir(self, event):  # wxGlade: MyFrame.<event_handler>
        self.setSolidPhysicalDBdir(event)

    #------------system--------------
    #system削除
    def onDeleteSystem(self, event):  # wxGlade: MyFrame.<event_handler>
        fileBox = self.list_box_s1
        self.deleteDirectFiles(fileBox, "system")

    #systemRename
    def onRenameSystem(self, event):  # wxGlade: MyFrame.<event_handler>
        fileBox = self.list_box_s1
        self.renameDirectFile(fileBox, "system")

    #systemFluidコピー
    def onCopyFluidSystem(self, event):  # wxGlade: MyFrame.<event_handler>
        fileBox = self.list_box_s1
        self.copyFiles(fileBox, "fluid", "system")

    #systemSolidコピー
    def onCopySolidSystem(self, event):  # wxGlade: MyFrame.<event_handler>
        fileBox = self.list_box_s1
        self.copyFiles(fileBox, "solid", "system")

    #systemFluid戻す
    def onReturnFluidSystem(self, event):  # wxGlade: MyFrame.<event_handler>
        fileBox = self.list_box_s2
        regionBox = self.list_box_s3
        self.returnFiles(fileBox, regionBox, "system")

    #systemSolid戻す
    def onReturnSolidSystem(self, event):  # wxGlade: MyFrame.<event_handler>
        fileBox = self.list_box_s4
        regionBox = self.list_box_s5
        self.returnFiles(fileBox, regionBox, "system")

    #systemFluid削除
    def onDeleteSystemFluid(self, event):  # wxGlade: MyFrame.<event_handler>
        fileBox = self.list_box_s2
        self.deleteFiles(fileBox, "fluid", "system")

    #systemFluid編集
    def onEditSystemFluid(self, event):  # wxGlade: MyFrame.<event_handler>
        fileBox = self.list_box_s2
        regionBox = self.list_box_s3
        self.editFiles(fileBox, regionBox, "system")

    #systemSolid削除
    def onDeleteSystemSolid(self, event):  # wxGlade: MyFrame.<event_handler>
        fileBox = self.list_box_s4
        self.deleteFiles(fileBox, "solid", "system")

    #systemSolid編集
    def onEditSystemSolid(self, event):  # wxGlade: MyFrame.<event_handler>
        fileBox = self.list_box_s4
        regionBox = self.list_box_s5
        self.editFiles(fileBox, regionBox, "system")

    #------------close--------------
    #close
    def onClose(self, event):  # wxGlade: MyFrame.<event_handler>
        self.Destroy()

    #------------固体の材料設定--------------
    #regionMaterial編集
    def onEditRegionMaterial(self, event): # wxGlade: MyFrame.<event_handler>
        self.editMaterialFile("region")

    #regionMterial名変更
    def onRenameRegionMaterial(self, event): # wxGlade: MyFrame.<event_handler>
        self.renameRegionMaterial(event)

    #materialDB登録
    def onSaveMaterialDB(self, event): # wxGlade: MyFrame.<event_handler>
        self.saveMaterialDB(event)

    #候補材料をregionにセット
    def onSetMaterialToRegion(self, event): # wxGlade: MyFrame.<event_handler>
        self.setMaterialToRegion(event)

    def onEditMaterialDB(self, event): # wxGlade: MyFrame.<event_handler>
        self.editMaterialFile("DB")

    #materialDBを開く
    def onOpenMaterialDBfolder(self, event): # wxGlade: MyFrame.<event_handler>
        self.openMaterialDB(event)

    #materialDBの材料名をlistBoxにセット
    def onSetMaterialToListBox(self, event): # wxGlade: MyFrame.<event_handler>
        self.setMaterialToListBox(event)

    #候補材料のクリア
    def onClearMatReq(self, event): # wxGlade: MyFrame.<event_handler>
        self.clearMatReq(event)

    #regionFolderを開く
    def onOpenRegionFolder(self, event): # wxGlade: MyFrame.<event_handler>
        self.openRegionFolder("constant", self.list_box_sm1)

    #solidMaterialを開く
    def onOpenSolidMaterial(self, event): # wxGlade: MyFrame.<event_handler>
        self.openRegionFile("constant", self.list_box_sm2)

    #materialDB内のfileを開く
    def onOpenMaterialDB(self, event): # wxGlade: MyFrame.<event_handler>
        self.openMaterialDBfile()

    #------file open-----
    #time
    def onOpenTime(self, event): # wxGlade: MyFrame.<event_handler>
        self.openOrgFile(event, iniTime)

    #timeFluid
    def onOpenTimeFluid(self, event): # wxGlade: MyFrame.<event_handler>
        self.openFluidFile(event, iniTime)

    #timeSold
    def onOpenTimeSolid(self, event): # wxGlade: MyFrame.<event_handler>
        self.openSolidFile(event, iniTime)

    #constant
    def onOpenConstant(self, event): # wxGlade: MyFrame.<event_handler>
        self.openOrgFile(event, "constant")

    #constantFluid
    def onOpenConstantFluid(self, event): # wxGlade: MyFrame.<event_handler>
        self.openFluidFile(event, "constant")

    #constantSolid
    def onOpenConstantSolid(self, event): # wxGlade: MyFrame.<event_handler>
        self.openSolidFile(event, "constant")

    #system
    def onOpenSystem(self, event): # wxGlade: MyFrame.<event_handler>
        self.openOrgFile(event, "system")

    #systemFluid
    def onOpenSystemFluid(self, event): # wxGlade: MyFrame.<event_handler>
        self.openFluidFile(event, "system")

    #systemSolid
    def onOpenSystemSolid(self, event): # wxGlade: MyFrame.<event_handler>
        self.openSolidFile(event, "system")

    #----rename------
    #renameTimeFluid
    def onRenameTimeFluid(self, event):  # wxGlade: MyFrame.<event_handler>
        fileBox = self.list_box_2
        self.renameFiles(fileBox, "fluid", iniTime)

    #renameTimeSolid
    def onRenameTimeSolid(self, event):  # wxGlade: MyFrame.<event_handler>
        fileBox = self.list_box_4
        #self.deleteFiles(fileBox, "solid", iniTime)
        self.renameFiles(fileBox, "solid", iniTime)

    #renameConstantFluid
    def onRenameConstantFluid(self, event):  # wxGlade: MyFrame.<event_handler>
        fileBox = self.list_box_c2
        self.renameFiles(fileBox, "fluid", "constant")

    #renameConstantSolid
    def onRenameConstantSolid(self, event):  # wxGlade: MyFrame.<event_handler>
        fileBox = self.list_box_c4
        self.renameFiles(fileBox, "solid", "constant")

    #renameSystemFluid
    def onRenameSystemFluid(self, event):  # wxGlade: MyFrame.<event_handler>
        fileBox = self.list_box_s2
        self.renameFiles(fileBox, "fluid", "system")

    #renameSystemSolid
    def onRenameSystemSolid(self, event):  # wxGlade: MyFrame.<event_handler>
        fileBox = self.list_box_s4
        self.renameFiles(fileBox, "solid", "system")

    #csvFileで設定
    def onSetCSVFile(self, event):  # wxGlade: MyFrame.<event_handler>
        self.setCSVFile(event)

    #fileに出力
    def onOutputCSVFile(self, event):  # wxGlade: MyFrame.<event_handler>
        self.outputCsvFile(event)


# end of class MyFrame

    #  checkInListDclick
    #  Dclick時のevent確認（list_ctrl_1）
    def checkInListDclick(self, event):
        pos = event.GetPositionTuple()
        selectRegion = ""
        row = 0
        for item in solidRegions:
            if self.list_ctrl_1.IsSelected(row) == True:
                selectRegion = item
                break
            row += 1
        colWidth = [self.list_ctrl_1.GetColumnWidth(0),
                    self.list_ctrl_1.GetColumnWidth(1),
                    self.list_ctrl_1.GetColumnWidth(2)]
        if pos[0] <= colWidth[0]:
            #regionFolderを開く
            self.openRegionNameFolder("constant", selectRegion)
        elif pos[0] <= colWidth[0] + colWidth[1]:
            #現在の設定材を開く
            self.openRegionNameFile("constant", selectRegion)
        else:
            #候補材を設定
            self.setMaterialToListBox(event)

    #  reloadData
    #    deta再読み込み（pageChangeの時）
    def reloadData(self, event):
        initialize()
        self.setFileNameMaterialToListBox()
        self.setFileNameToListBox()

    #  openMaterialDBfile
    #    materialDB内のfileを開く
    def openMaterialDBfile(self):
        row = 0
        selectName = ""
        for name in solidPhysicalDB:
            if self.list_ctrl_2.IsSelected(row) == True:
                selectName = self.list_ctrl_2.GetItemText(row)
                break
            row += 1
        fileName = solidPhysicalDBdir + "/" + selectName
        pyTreeFoam.runEditor(fileName)

    #  openRegionFile
    #    region内のfileを開く
    def openRegionFile(self, folder, listBox):
        n = listBox.GetSelection()
        region = solidRegions[n]
        self.openRegionNameFile(folder, region)

    def openRegionNameFile(self, folder, region):
        #name = "solidThermophysicalProperties"
        name = solidPhysicalDBdir.split("/")[-1]
        fileName = os.getcwd() + "/" + folder + "/" + region + "/" + name
        pyTreeFoam.runEditor(fileName)

    #  openRegionFolder
    #    regionFolderを開く
    def openRegionFolder(self, folder, listBox):
        name = listBox.GetStringSelection()
        self.openRegionNameFolder(folder, name)

    def openRegionNameFolder(self, folder, name):    
        openRegionDir = os.getcwd() + "/" + folder + "/" + name
        pyTreeFoam.openFolderNautilus(openRegionDir)
        #os.system(("nautilus " + openRegionDir).encode("utf-8"))

    #  outputCsvFile
    #    csvFileを出力する
    def outputCsvFile(self, event):
        #file名の取得
        inputTextDDialog.title = u"file名の入力"
        inputTextDDialog.message = u"出力するcsvファイルのファイル名を入力してください。"
        inputTextDDialog.inputText = "regionMaterial.csv"
        dialog = inputTextDDialog.MyDialog(None)
        result = dialog.ShowModal()
        if inputTextDDialog.status == "OK":
            text = inputTextDDialog.inputText
            csvFileName = os.getcwd() + "/" + text
        else:
            return

        #出力データの作成
        cont  = "region,material\n"
        i = 0
        for region in solidRegions:
            material = constantSolidPhysical[i]
            cont += ",".join([region, material]) + "\n"
            i += 1
        f=open(csvFileName, "w")
        f.write(cont)
        f.close()
        title = u"csvFileの作成"
        message = u"現在の材料設定（region,material）を出力しました。"
        self.okDialog(title, message)

    #  setCSVFile
    #    csvFileを読み込み、各regionに一括して材料名をセット
    def setCSVFile(self, event):
        global solidRegions, constantSolidPhysicalReq, constantSolidPhysical
        global solidPhysicalDB
        title = u"fileの選択"
        message  = u"各regionの材料を設定したcsvfileを選択してください。\n"
        message += u"（csvFileは、regin名と材料名のセットで準備する。）"
        currDir = os.getcwd()
        fileFilter = "*.csv"
        [stat, csvFileName] = getOpenFileDDialogShow(title, message, 
                                currDir, fileFilter)
        if stat != "OK":
            return

        #csvFile読み込み
        dataFile = currDir + "/" + csvFileName
        data = readCsvData(dataFile)
        #エラーチェック
        error = self.csvErrorCheck(data, solidRegions, solidPhysicalDB)
        if error != "OK":
            return

        #読み込んだデータをconstantSolidPhysicalReqにセット
        constantSolidPhysicalReq = []
        row = 0
        for regName in solidRegions:
            flag = 0
            for line in data:
                if regName == line[0]:
                    constantSolidPhysicalReq.append(line[1])
                    flag = 1
                    break
            if flag == 0:
                constantSolidPhysicalReq.append("")
            row += 1
        #データをセット
        properties = solidProperties
        row = 0
        for regName in solidRegions:
            if constantSolidPhysicalReq[row] != "":
                fileName = solidPhysicalDBdir + "/" + constantSolidPhysicalReq[row]
                comm  = "cp " + fileName + " " + currDir + "/constant/" + regName
                comm += "/" + properties
                os.system(comm)
            row += 1
        initialize()
        self.setFileNameMaterialToListBox()
        title = u"データの一括セット"
        message = u"csvFile「" + csvFileName + u"」の材料データを各regionにセットしました。"
        self.okDialog(title, message)

    #  csvErrorCheck
    #    読み込んだcsvデータのエラーチェック
    def csvErrorCheck(self, data, regions, physicalDB):
        #未定義材料のチェック
        unDefineMat = []
        for regMat in data:
            sameFlag = 0
            for mat in physicalDB:
                if regMat[1] == mat:
                    sameFlag = 1
                    break
            if sameFlag == 0:
                unDefineMat.append(regMat[1])
        if len(unDefineMat) > 0:
            title = u"エラー"
            message  = u"csvFile内に、DBで定義されていない材料があります。\n"
            message += u"「"
            if len(unDefineMat) > 10:
                names = ",".join(unDefineMat[:10]) + "..."
            else:
                names = ",".join(unDefineMat)
            message += names + u"」が未定義です。"
            self.errDialog(title, message)
            return "error"
        #未定義regionチェック
        unDefine = []
        for regMat in data:
            sameFlag = 0
            for regName in regions:
                if regName == regMat[0]:
                    sameFlag = 1
                    break
            if sameFlag == 0:
                unDefine.append(regMat[0])
        if len(unDefine) > 0:
            title = u"エラー"
            message  = u"csvFile内に、存在しないregion名があります。\n"
            message += u"「"
            if len(unDefine) > 10:
                names = ",".join(unDefine[:10]) + "..."
            else:
                names = ",".join(unDefine)
            message += names + u"」が存在しません。"
            self.errDialog(title, message)
            return "error"
        #region洩れのチェック
        unDefine = []
        for regName in regions:
            sameFlag = 0
            for regMat in data:
                if regName == regMat[0]:
                    sameFlag = 1
                    break
            if sameFlag == 0:
                unDefine.append(regName)
        if len(unDefine) > 0:
            title = u"エラー"
            message  = u"以下のregionは、csvFile内に存在しません。\n"
            message += u"「"
            if len(unDefine) > 10:
                names = ",".join(unDefine[:10]) + "..."
            else:
                names = ",".join(unDefine)
            message += names + u"」は、材料が設定できません。"
            self.errDialog(title, message)
            return "error"
        return "OK"

    #  setMaterialToRegion
    #    候補材料をregionにセット
    def setMaterialToRegion(self, event):
        global constantSolidPhysical, constantSolidPhysicalReq
        nReg = len(solidRegions)
        setName = []
        i = 0
        while i<nReg:
            currMat = constantSolidPhysical[i]
            reqMat  = constantSolidPhysicalReq[i]
            if currMat != reqMat:
                setName.append([i, reqMat])
            i += 1
        currDir = os.getcwd()
        #OFversionチェック
        properties = solidProperties
        for name in setName:
            fileName = solidPhysicalDBdir + "/" + name[1]
            newFile = currDir + "/constant/"
            newFile += solidRegions[name[0]] + "/" + properties
            os.system("rm " + newFile)
            comm  = "cp " + fileName + " " + newFile
            os.system(comm)
        initialize()
        self.setFileNameMaterialToListBox()

    #  clearMatReq
    #    候補材料をクリア
    def clearMatReq(self, event):
        initialize()
        self.setFileNameMaterialToListBox()

    #  setMaterialToListBox
    #    材料を候補材としてlistBoxにセット
    def setMaterialToListBox(self, event):
        global constantSolidPhysicalReq
        #材料DBの選択行を検索
        material = ""
        row = 0
        for name in solidPhysicalDB:
            if self.list_ctrl_2.IsSelected(row) == True:
                material = self.list_ctrl_2.GetItemText(row)
                break
            row += 1

        #nMat = self.list_box_sm4.GetSelections()
        if material == "":
            title = u"エラー"
            mess = u"材料DB内の材料名を選択していません。\n材料名を選択後、クリックして材料を設定してください。"
            self.errDialog(title, mess)
            return
        #material = self.list_box_sm4.GetString(nMat[0])
        fileName = solidPhysicalDBdir + "/" + material
        self.checkPhysicalCont(fileName)
        #選択行を検索
        row = 0
        selectRegion = ""
        for region in solidRegions:
            if self.list_ctrl_1.IsSelected(row) == True:
                selectRegion = region
                break
            row += 1
        #候補材を設定
        self.list_ctrl_1.SetStringItem(row, 2, material)
        constantSolidPhysicalReq[row] = material

    #  openMaterialDB
    #    materialDBを開く
    def openMaterialDB(self, event):
        openDir = solidPhysicalDBdir
        pyTreeFoam.openFolderNautilus(openDir)
        #os.system(("nautilus " + openDir).encode("utf-8"))

    #  saveMaterialDB
    #    materialDB登録
    def saveMaterialDB(self, event):
        #選択行を検索
        row = 0
        nReg = 0
        selectRegion = ""
        for region in solidRegions:
            if self.list_ctrl_1.IsSelected(row) == True:
                selectRegion = region
                nReg = row
                break
            row += 1
        #errorチェック
        if selectRegion == "":
            title = u"エラー"
            mess = u"材料名を選択してください。"
            self.errDialog(title, mess)
            return
        #材料を登録
        regName = self.list_ctrl_1.GetItemText(nReg)
        fileName  = os.getcwd() + "/constant/" + regName
        properties = solidProperties
        fileName += "/" + properties
        material = getMaterial(fileName)
        if material == "-":
            title = u"エラー"
            mess = u"材料名を設定してください。"
            self.errDialog(title, mess)
            return
        comm = "cp " + fileName + " " + solidPhysicalDBdir + "/" + material
        os.system(comm)
        initialize()
        self.setFileNameMaterialToListBox()        

    #  renameRegionMaterial
    #    regionMaterial名変更
    def renameRegionMaterial(self, event):
        #選択行を検索
        row = 0
        nReg = 0
        selectRegion = ""
        for region in solidRegions:
            if self.list_ctrl_1.IsSelected(row) == True:
                selectRegion = region
                nReg = row
                break
            row += 1
        #errorチェック
        if selectRegion == "":
            title = u"エラー"
            mess = u"材料名を選択してください。"
            self.errDialog(title, mess)
            return
        #rename
        regName = self.list_ctrl_1.GetItemText(nReg)
        fileName  = os.getcwd() + "/constant/" + regName
        properties = solidProperties
        fileName += "/" + properties
        material = getMaterial(fileName)
        title = u"材料名の変更"
        message = u"新しい材料名を入力してください。"
        newMaterial = self.textDialog(title, message, material)
        if newMaterial == "":
            return
        setMaterial(fileName, newMaterial)
        initialize()
        self.setFileNameMaterialToListBox()        


    #  editMaterialFile
    #    材料fileを開く
    def editMaterialFile(self, folder):
        #選択行を検索
        row = 0
        nReg = 0
        selectRegion = ""
        for region in solidRegions:
            if self.list_ctrl_1.IsSelected(row) == True:
                selectRegion = region
                nReg = row
                break
            row += 1
        #処理
        if folder == "region":
            #errorチェック
            if selectRegion == "":
                title = u"エラー"
                mess = u"材料名を選択してください。"
                self.errDialog(title, mess)
                return
            #regionフォルダをひらく
            regName = self.list_ctrl_1.GetItemText(nReg)
            fileName  = os.getcwd() + "/constant/" + regName
            properties = solidProperties
            fileName += "/" + properties
        else:
            #材料DBファイルを開く
            n = 0
            selName = ""
            for name in solidPhysicalDB:
                if self.list_ctrl_2.IsSelected(n) == True:
                    selName = solidPhysicalDB[n]
                    break
                n += 1
            print n
            if selName == "":
                title = u"エラー"
                mess = u"材料名を選択してください。"
                self.errDialog(title, mess)
                return
            fileDir = solidPhysicalDBdir
            fileName = fileDir + "/" + selName
        pyTreeFoam.runEditor(fileName)

    #  renameFiles
    #    folder内のfile名を変更
    def renameFiles(self, fileBox, FluidSolid, renameFolder):
        nFiles = fileBox.GetSelections()
        if len(nFiles) == 0:
            title = u"エラー"
            mess = u"fileを選択してください。"
            self.errDialog(title, mess)
            return
        if len(nFiles) != 1:
            title = u"エラー"
            mess = u"一度に複数のfile名を変更できません。\n  1ヶのfileを選択してください。"
            self.errDialog(title, mess)
            return

        if FluidSolid == "fluid":
            regions = fluidRegions
        else:
            regions = solidRegions
        folders = []
        for region in regions:
            folder = os.getcwd() + "/" + renameFolder + "/" + region
            folders.append(folder)
        renFileName = fileBox.GetString(nFiles[0])
        title = u"file名の変更"
        mess = u"選択したfileのfile名を変更します。"
        newFileName = self.textDialog(title, mess, renFileName)
        if newFileName == "":
            return

        print "file名を変更します。"
        for folder in folders:
            newNamePath = folder + "/" + newFileName
            renNamePath = folder + "/" + renFileName
            renNamePath = getFoamContents.checkFileName(renNamePath)
            if renNamePath[-3:] == ".gz":
                newNamePath += ".gz"
            comm = "mv " + renNamePath + " " + newNamePath
            print comm
            os.system(comm)
        initialize()
        self.setFileNameToListBox()

    #  openOrgFile
    #    各folder内のfileを開く
    def openOrgFile(self, event, folder):
        if folder == iniTime:
            fileBox = self.list_box_1
        elif folder == "constant":
            fileBox = self.list_box_c1
        else:
            fileBox = self.list_box_s1
        nFile = fileBox.GetSelections()
        fileName = ""
        header = os.getcwd() + "/" + folder + "/"
        #fileName += header + fileBox.GetString(nFile[0]) + " "
        fileName += header + fileBox.GetString(nFile[0])
        fileName = getFoamContents.checkFileName(fileName)
        pyTreeFoam.runEditor(fileName)

    #  openFluidFile
    #    fluid内のfileを開く
    def openFluidFile(self, event, folder):
        if folder == iniTime:
            fileBox = self.list_box_2
            regBox = self.list_box_3
        elif folder == "constant":
            fileBox = self.list_box_c2
            regBox = self.list_box_c3
        else:
            fileBox = self.list_box_s2
            regBox = self.list_box_s3
        nFile = fileBox.GetSelections()
        name = fileBox.GetString(nFile[0])
        regName = regBox.GetStringSelection()
        if regName == "":
            title = u"エラー"
            mess = u"regionを選択してください。"
            self.errDialog(title, mess)
            return
        fileName = os.getcwd() + "/" + folder + "/" + regName + "/" + name
        fileName = getFoamContents.checkFileName(fileName)
        pyTreeFoam.runEditor(fileName)

    #  openSolidFile
    #    Solid内のfileを開く
    def openSolidFile(self, event, folder):
        if folder == iniTime:
            fileBox = self.list_box_4
            regBox = self.list_box_5
        elif folder == "constant":
            fileBox = self.list_box_c4
            regBox = self.list_box_c5
        else:
            fileBox = self.list_box_s4
            regBox = self.list_box_s5
        nFile = fileBox.GetSelections()
        name = fileBox.GetString(nFile[0])
        regName = regBox.GetStringSelection()
        if regName == "":
            title = u"エラー"
            mess = u"regionを選択してください。"
            self.errDialog(title, mess)
            return
        fileName = os.getcwd() + "/" + folder + "/" + regName + "/" + name
        fileName = getFoamContents.checkFileName(fileName)
        pyTreeFoam.runEditor(fileName)

    #  renameDirectFile
    #    folder直下のfileのrename
    def renameDirectFile(self, fileBox, renFolder):
        nFiles = fileBox.GetSelections()
        if len(nFiles) == 0:
            title = u"エラー"
            mess = u"fileを選択してください。"
            self.errDialog(title, mess)
            return
        if len(nFiles) != 1:
            title = u"エラー"
            mess = u"複数のfileは、選択できません。"
            self.errDialog(title, mess)
            return
        name = fileBox.GetString(nFiles[0])
        oldFileName = os.getcwd() + "/" + renFolder + "/" + name
        inputTextDDialog.title = u"file名の変更"
        inputTextDDialog.message = u"新しいファイル名を入力してください。"
        inputTextDDialog.inputText = name
        dialog = inputTextDDialog.MyDialog(None)
        result = dialog.ShowModal()
        if inputTextDDialog.status == "OK":
            name = inputTextDDialog.inputText
            fileName = os.getcwd() + "/" + renFolder + "/" + name
        else:
            return
        oldFileName = getFoamContents.checkFileName(oldFileName)
        if oldFileName[-3:] == ".gz":
            fileName += ".gz"
        comm = "mv " + oldFileName + " " + fileName
        os.system(comm)
        initialize()
        self.setFileNameToListBox()


    #  deleteDirectFiles
    #    folder直下のfile削除
    def deleteDirectFiles(self, fileBox, delFolder):
        nFiles = fileBox.GetSelections()
        if len(nFiles) == 0:
            title = u"エラー"
            mess = u"fileを選択してください。"
            self.errDialog(title, mess)
            return
        title = u"file削除"
        mess = u"fileをゴミ箱に移動します。"
        stat = self.okCancelDialog(title, mess)
        if stat != "OK":
            return
        delFiles = []
        for n in nFiles:
            name = fileBox.GetString(n)
            delFiles.append(name)
        folder = os.getcwd() + "/" + delFolder
        for name in delFiles:
            delName = folder + "/" + name
            delName = getFoamContents.checkFileName(delName)
            obj = gio.File(delName.encode("utf-8"))
            obj.trash()
        initialize()
        self.setFileNameToListBox()


    #  deleteFiles
    #    file削除
    def deleteFiles(self, fileBox, FluidSolid, deleteFolder):
        nFiles = fileBox.GetSelections()
        if len(nFiles) == 0:
            title = u"エラー"
            mess = u"fileを選択してください。"
            self.errDialog(title, mess)
            return
        if FluidSolid == "fluid":
            regions = fluidRegions
        else:
            regions = solidRegions
        folders = []
        for region in regions:
            folder = os.getcwd() + "/" + deleteFolder + "/" + region
            folders.append(folder)
        deleteFiles = []
        for n in nFiles:
            name = fileBox.GetString(n)
            deleteFiles.append(name)
        for folder in folders:
            for name in deleteFiles:
                delName = folder + "/" + name
                delName = getFoamContents.checkFileName(delName)
                #ゴミ箱に移動できなかった場合、削除する
                try:
                    obj = gio.File(delName.encode("utf-8"))
                    obj.trash()
                except:
                    comm = "rm " + delName
                    print comm
                    os.system(comm)
        initialize()
        self.setFileNameToListBox()


    #  copyFiles
    #    fileコピー
    def copyFiles(self, fileBox, FluidSolid, copyFolder):
        nFiles = fileBox.GetSelections()
        if len(nFiles) == 0:
            title = u"エラー"
            mess = u"fileを選択してください。"
            self.errDialog(title, mess)
            return
        if FluidSolid == "fluid":
            regions = fluidRegions
        else:
            regions = solidRegions
        folders = []
        for region in regions:
            folder = os.getcwd() + "/" + copyFolder + "/" + region
            folders.append(folder)
        copyFiles = []
        for n in nFiles:
            name = fileBox.GetString(n)
            copyFile = os.getcwd() + "/" + copyFolder + "/" + name
            copyFile = getFoamContents.checkFileName(copyFile)
            copyFiles.append(copyFile)
        for folder in folders:
            for copyFile in copyFiles:
                comm = "cp " + copyFile + " " + folder
                os.system(comm)
        initialize()
        self.setFileNameToListBox()

    #  returnFiles
    #    fileを戻す
    def returnFiles(self, fileBox, regionBox, toCopyFolder):
        nFiles = fileBox.GetSelections()
        if len(nFiles) == 0:
            title = u"エラー"
            mess = u"戻すfileを選択してください。"
            self.errDialog(title, mess)
            return
        regNameFlag = 0
        regionName = regionBox.GetStringSelection()
        if regionName == "":
            regNameFlag = 1
            regionName = regionBox.GetString(0)
        caseDir = os.getcwd()
        folder = caseDir + "/" + toCopyFolder
        for n in nFiles:
            name = fileBox.GetString(n)
            copyFile = caseDir + "/" + toCopyFolder + "/" + regionName + "/" + name
            copyFile = getFoamContents.checkFileName(copyFile)
            comm = "cp " + copyFile + " " + folder
            os.system(comm)
        if regNameFlag == 1:
            title = u"fileを戻す"
            mess = u"region名を選択していないので、" + regionName + u" のfileを戻しました。"
            self.okDialog(title, mess)
        initialize()
        self.setFileNameToListBox()


    #  editFiles
    #    file編集
    def editFiles(self, fileBox, regionBox, editFolder):
        nFiles = fileBox.GetSelections()
        if len(nFiles) == 0:
            title = u"エラー"
            mess = u"コピーするfileを選択してください。"
            self.errDialog(title, mess)
            return
        regionName = regionBox.GetStringSelection()
        if regionName == "":
            title = u"エラー"
            mess = u"regionを選択してください。"
            self.errDialog(title, mess)
            return
        folder = os.getcwd() + "/" + editFolder + "/" + regionName
        openFiles = ""
        for n in nFiles:
            name = fileBox.GetString(n)
            fileName = getFoamContents.checkFileName(folder + "/" + name)
            openFiles += fileName + " "
        pyTreeFoam.runEditor(openFiles)

    #
    #  checkPhysicalCont
    #    thermophysicalProperties内のmaterialをチェック
    def checkPhysicalCont(self, fileName):
        f=open(fileName); cont=f.read(); f.close()
        p = cont.find("material")
        if p < 0:
            p = getFoamContents.skipFoamFileMem(cont, 0)
            [keyword, p] = getFoamContents.getKeywordMem(cont, p)
            i = p
            while i >= 0 and cont[i] != "\n":
                i -= 1
            addLine = "material    " + fileName.split("/")[-1] + ";\n\n"
            newCont = cont[:i] + addLine + cont[i+1:]
            f=open(fileName, "w"); f.write(newCont); f.close()
        else:
            ps = p
            [keyword, p] = getFoamContents.getKeywordMem(cont, p)
            [keyword, p] = getFoamContents.getKeywordMem(cont, p)
            material = fileName.split("/")[-1]
            if keyword != material:
                pe = getFoamContents.skipUntilCRMem(cont, ps)
                addLine = "material    " + material + ";"
                newCont = cont[:ps] + addLine + cont[pe:]
                f=open(fileName, "w"); f.write(newCont); f.close()

    #
    #  setSolidPhysicalDBdir
    #    solidPhysicalDBのdirをセット
    def setSolidPhysicalDBdir(self, event):
        global solidPhysicalDBdir
        title = u"固体用の物性値DBフォルダのセット"
        mess = u"固体の物性値データベースの保存先フォルダを設定します。"
        root = os.environ["HOME"]
        currDir = os.getcwd()
        selDir = solidPhysicalDBdir.encode("utf-8")
        [stat, selDir] = getOpenFolderDDialog.Show(title, mess, root, currDir, selDir)
        if stat == "OK":
            solidPhysicalDBdir = selDir
            self.text_ctrl_2.SetValue(selDir)
            setSolidDirMultiRegion_data(selDir)
            solidPhysicalDB = getSolidPhysicalDB(solidPhysicalDBdir)
            self.list_box_sm4.Clear()
            self.list_box_sm4.AppendItems(solidPhysicalDB)


    def setFileNameMaterialToListBox(self):
        #setFileName
        self.setFileNameToListBox()
        #constantSolidPhysical
        i = 0
        for name in solidRegions:
            self.list_ctrl_1.SetStringItem(i, 0, name)
            self.list_ctrl_1.SetStringItem(i, 1, constantSolidPhysical[i])
            self.list_ctrl_1.SetStringItem(i, 2, constantSolidPhysicalReq[i])
            i += 1
        #solidPhysicalDB
        self.list_ctrl_2.DeleteAllItems()
        i = 0
        for name in solidPhysicalDB:
            self.list_ctrl_2.InsertStringItem(i, name)
            #self.list_ctrl_2.SetStringItem(i, 0, name)
            i += 1
        #solidPhysicalDBdir
        self.text_ctrl_2.SetValue(solidPhysicalDBdir)

    def setFileNameToListBox(self):
        #timeFile
        self.list_box_1.Clear()
        self.list_box_1.AppendItems(timeFiles)
        self.list_box_2.Clear()
        self.list_box_2.AppendItems(timeFluidFiles)
        self.list_box_3.Clear()
        self.list_box_3.AppendItems(fluidRegions)
        self.list_box_4.Clear()
        self.list_box_4.AppendItems(timeSolidFiles)
        self.list_box_5.Clear()
        self.list_box_5.AppendItems(solidRegions)
        #constant
        self.list_box_c1.Clear()
        self.list_box_c1.AppendItems(constantFiles)
        self.list_box_c2.Clear()
        self.list_box_c2.AppendItems(constantFluidFiles)
        self.list_box_c3.Clear()
        self.list_box_c3.AppendItems(fluidRegions)
        self.list_box_c4.Clear()
        self.list_box_c4.AppendItems(constantSolidFiles)
        self.list_box_c5.Clear()
        self.list_box_c5.AppendItems(solidRegions)
        #system
        self.list_box_s1.Clear()
        self.list_box_s1.AppendItems(systemFiles)
        self.list_box_s2.Clear()
        self.list_box_s2.AppendItems(systemFluidFiles)
        self.list_box_s3.Clear()
        self.list_box_s3.AppendItems(fluidRegions)
        self.list_box_s4.Clear()
        self.list_box_s4.AppendItems(systemSolidFiles)
        self.list_box_s5.Clear()
        self.list_box_s5.AppendItems(solidRegions)
        #solidMaterial
        i = 0
        for name in solidRegions:
            self.list_ctrl_1.SetStringItem(i, 0, name)
            self.list_ctrl_1.SetStringItem(i, 1, constantSolidPhysical[i])
            self.list_ctrl_1.SetStringItem(i, 2, constantSolidPhysicalReq[i])
            i += 1

    def checkRegions(self):
        error = 0
        if len(fluidRegions) == 0 or len(solidRegions) == 0:
            error = 1
        else:
            if len(fluidRegions) != 0:
                region = os.getcwd() + "/constant/" + fluidRegions[0]
                if len(glob.glob(region)) == 0:
                    error = 1
            if len(solidRegions) != 0:
                region = os.getcwd() + "/constant/" + solidRegions[0]
                if len(glob.glob(region)) == 0:
                    error = 1
        if error == 1:
            title = u"エラー"
            mess = u"このcaseには、regionがありません。\n解析caseを確認してください。"
            self.errDialog(title, mess)


    def errDialog(self, title, message):
        dlg = wx.MessageDialog(self, message, title,
                               style = wx.OK | wx.ICON_HAND) 
        dlg.ShowModal()
        dlg.Destroy()

    def okDialog(self, title, message):
        dlg = wx.MessageDialog(self, message, title,
                               style = wx.OK | wx.ICON_INFORMATION) 
        dlg.ShowModal()
        dlg.Destroy()

    def okCancelDialog(self, title, message):
        dlg = wx.MessageDialog(self, message, title,
                             wx.OK | wx.CANCEL | wx.ICON_INFORMATION) 
        ans = dlg.ShowModal()
        stat = ""
        if ans == wx.ID_OK:
            stat = "OK"
        else:
            stat = "CANCEL"
        return stat

    def textDialog(self, title, message, defText):
        dlg = wx.TextEntryDialog(self, message, title, defaultValue=defText)
        ansBtn = dlg.ShowModal()
        ansTxt = dlg.GetValue()
        if ansBtn == wx.ID_OK:
            text = ansTxt
        else:
            text = ""
        return text

#
#  readCsvData
#    csvデータの読み込み
def readCsvData(fileName):
    cont = csv.reader(file(fileName))
    data = []
    for row in cont:
        if len(row)>0:
            data.append(row)
    return data[1:]

#
#  checkMaterialDBDir
#    materialDBDirをチェックし、無ければ作成する。
#　　defaultの場所は、「~/OpenFOAM/multiRegionDB/solid」
def checkMaterialDBDir():
    global solidPhysicalDBdir, iniDBdata, OFversion, solidProperties
    #OFversion取得
    config = pyTreeFoam.readConfigTreeFoam()
    OFversion = config[0]
    #solidProperties取得
    if OFversion >= "2.2.0":
        solidProperties = "thermophysicalProperties"
    else:
        solidProperties = "solidThermophysicalProperties"
    #現在の設定場所を確認する
    fileName = multiRegion_data
    setDir = ""
    f=open(fileName); cont=f.readlines(); f.close()
    for line in cont:
        if line.split()[0] == "solidPhysicalDBdir":
            setDir = line.split()[1]
            break

    iniDBdata = os.environ["TreeFoamPath"] + "/data/multiRegionDB/solid/" + solidProperties
    
    setFolder = setDir.split("/")[-1]
    if (len(glob.glob(setDir)) == 0 or setFolder != solidProperties):
        #materialDBDirが無い場合、defaultの場所に設定する
        homeDir = os.environ["HOME"]
        DBdir = homeDir + "/OpenFOAM"
        if len(glob.glob(DBdir)) == 0:
            os.system("mkdir " + DBdir)
        DBdir += "/multiRegionDB"
        if len(glob.glob(DBdir)) == 0:
            os.system("mkdir " + DBdir)
        DBdir += "/solid"
        if len(glob.glob(DBdir)) == 0:
            os.system("mkdir " + DBdir)
        properties = solidProperties
        #iniDBdata = os.environ["TreeFoamPath"] + "/data/multiRegionDB/solid/" + properties
        DBdir += "/" + properties
        if len(glob.glob(DBdir)) == 0:
            os.system("mkdir " + DBdir)
        #setSolidDirMultiRegion_data(DBdir)
        setDir = DBdir

    if len(glob.glob(setDir + "/*")) == 0:
        sourceDir = iniDBdata
        comm = "cp " + sourceDir + "/* " + setDir + " > /dev/null"
        os.system(comm)
        #書き込めなかった場合、treeFoam内のdirを設定
        if len(glob.glob(setDir + "/*")) == 0:
            setDir = iniDBdata
    setSolidDirMultiRegion_data(setDir)

#
#  initialize
#
def initialize():
    global fluidRegions, solidRegions
    global iniTime, timeFiles, timeFluidFiles, timeSolidFiles
    global constantFiles, constantFluidFiles, constantSolidFiles
    global systemFiles, systemFluidFiles, systemSolidFiles
    global constantSolidPhysical, solidPhysicalDBdir, solidPhysicalDB
    global constantSolidPhysicalReq
    global OFversion, solidProperties
    caseDir = os.getcwd()
    #regionProperties有無チェック
    fileName = caseDir + "/constant/regionProperties"
    if len(glob.glob(fileName)) == 0:
        print "regionPropertiesが存在しません"
        return
    #regionの取得
    [fluidRegions, solidRegions] = getRegionName(caseDir)
    if len(fluidRegions) == 0 or len(solidRegions) == 0:
        return
    #timeFolder取得
    #iniTime = pyTreeFoam.getTimeFolders(caseDir)[0]
    iniTime = getFoamContents.getCurrTimeFolder(caseDir)
    #timeFile取得
    timeFiles = pyTreeFoam.getFieldNames(caseDir + "/" + iniTime)
    timeFluidFiles = pyTreeFoam.getFieldNames(caseDir + "/" + iniTime + "/" + fluidRegions[0])
    timeSolidFiles = pyTreeFoam.getFieldNames(caseDir + "/" + iniTime + "/" + solidRegions[0])
    #constantFile取得
    [folders, files] = pyTreeFoam.getFoldersFiles(caseDir + "/constant")
    constantFiles = checkFileName(files)
    [folders, files] = pyTreeFoam.getFoldersFiles(caseDir + "/constant/"  + fluidRegions[0])
    constantFluidFiles = checkFileName(files)
    [folders, files] = pyTreeFoam.getFoldersFiles(caseDir + "/constant/"  + solidRegions[0])
    constantSolidFiles = checkFileName(files)
    #systemFile取得
    [folders, files] = pyTreeFoam.getFoldersFiles(caseDir + "/system")
    systemFiles = checkFileName(files)
    [folders, files] = pyTreeFoam.getFoldersFiles(caseDir + "/system/"  + fluidRegions[0])
    systemFluidFiles = checkFileName(files)
    [folders, files] = pyTreeFoam.getFoldersFiles(caseDir + "/system/"  + solidRegions[0])
    systemSolidFiles = checkFileName(files)
    #DBdata取得
    solidPhysicalDBdir = getSolidDirMultiRegion_data()
    solidPhysicalDB = getSolidPhysicalDB(solidPhysicalDBdir)
    #各regionのsolidPhysicalFile取得
    constantSolidPhysical = []
    constantSolidPhysicalReq = []
    properties = solidPhysicalDBdir.split("/")[-1]
    for solidRegion in solidRegions:
        fileName = caseDir+"/constant/"+solidRegion+"/"+properties
        if len(glob.glob(fileName)) != 0:
            material = getMaterial(fileName)
        else:
            material = ""
        constantSolidPhysical.append(material)
        constantSolidPhysicalReq.append(material)


def getSolidPhysicalDB(solidPhysicalDBdir):
    DBdir = solidPhysicalDBdir
    if len(glob.glob(DBdir)) != 0:
        [folders, fileNames] = pyTreeFoam.getFoldersFiles(DBdir)
        if len(fileNames) == 0:
            #fileが無かった場合、fileをコピーする。
            setDBFilesToDBDir(DBdir)
        files = []
        for fileName in fileNames:
            files.append(fileName.split("/")[-1])
        solidPhysicalDB = checkFileName(files)
        files = []
        for fileName in solidPhysicalDB:
            fileDir = DBdir + "/" + fileName
            if isSolidThermophysicalProperties(fileDir) == True:
                files.append(fileName)
        solidPhysicalDB = checkFileName(files)
        return solidPhysicalDB


def setDBFilesToDBDir(DbDir):
    global iniDBdata
    folder = DbDir.split("/")[-1]
    iniDBdataDir = "/".join(iniDBdata.split("/")[:-1]) + "/" + folder
    comm = "cp " + iniDBdataDir + "/* " + DbDir
    print comm
    os.system(comm)
    
    

def isSolidThermophysicalProperties(fileName):
    f=open(fileName); cont=f.read(); f.close()
    word = fileName.split("/")[-2]
    p = cont.find(word)
    if p>=0:
        return True
    else:
        return False


def getSolidDirMultiRegion_data():
    global solidProperties
    fileName = multiRegion_data
    DBdir = solidPhysicalDBdir
    try:
        f=open(fileName); cont=f.readlines(); f.close()
        for line in cont:
            p = line.find("solidPhysicalDBdir")
            if p>=0:
                DBdir = line.split()[1]
                break
        if len(glob.glob(DBdir)) == 0:
            DBdir = solidPhysicalDBdir
    except:
        DBdir = solidPhysicalDBdir
    #OFversionに合わせDBdirを設定
    wdir = DBdir.split("/")[:-1]
    DBdir = "/".join(wdir) + "/" + solidProperties
    return DBdir

def setSolidDirMultiRegion_data(selDir):
    fileName = multiRegion_data
    f=open(fileName); cont=f.readlines(); f.close()
    i = 0
    while i<len(cont):
        p = cont[i].find("solidPhysicalDBdir")
        if p>= 0:
            cont[i] = "solidPhysicalDBdir " + selDir + "\n"
            break
        i += 1
    f=open(fileName, "w")
    for line in cont:
        f.write(line)
    f.close();


def getMaterial(fileName):
    f=open(fileName); cont=f.read(); f.close()
    p = getFoamContents.getKeywordPointerMem("material", cont, 0)
    if p<0:
        material = "-"
    else:
        while p<len(cont) and cont[p] != " ":
            p += 1
        [material, p] = getFoamContents.getKeywordMem(cont, p)
    return material

def setMaterial(fileName, material):
    f=open(fileName); cont=f.read(); f.close()
    p = cont.find("material")
    if p>=0:
        newCont = changeMaterial(cont, p, material)
    else:
        newCont = insertMaterial(cont, material)
    f=open(fileName, "w"); f.write(newCont); f.close()

def changeMaterial(cont, p, material):
    ps = p
    [keyword, p] = getFoamContents.getKeywordMem(cont, p)
    [keyword, p] = getFoamContents.getKeywordMem(cont, p)
    pe = getFoamContents.skipUntilCRMem(cont, ps)
    addLine = "material    " + material + ";"
    newCont = cont[:ps] + addLine + cont[pe:]
    return newCont

def insertMaterial(cont, material):
    p = getFoamContents.skipFoamFileMem(cont, 0)
    [keyword, p] = getFoamContents.getKeywordMem(cont, p)
    i = p
    while i >= 0 and cont[i] != "\n":
        i -= 1
    addLine = "\nmaterial    " + material + ";\n\n"
    newCont = cont[:i] + addLine + cont[i+1:]
    return newCont

def getRegionName(caseDir):
    [fluidRegions, solidRegions] = pyTreeFoam.getZonesInRegionProperties(caseDir)
    return [fluidRegions, solidRegions]

def checkFileName(files):
    ans = []
    for name in files:
        if name[0] != "." and name[-1] != "~" and name != "README":
            ans.append(name)
    return ans 


if __name__ == "__main__":
    app = wx.PySimpleApp(0)
    wx.InitAllImageHandlers()
    frame_1 = MyFrame(None, -1, "")
    app.SetTopWindow(frame_1)
    frame_1.Show()
    app.MainLoop()
