#!/usr/bin/env python
# -*- coding: utf-8 -*-
#
#  setFoamContents
#      Foam形式のデータを作成する
#
#       10/03/04    新規作成
#       13/04/01    remakeTergetBoundaryFieldsのバグ修正。
#                   boundaryFieldが書き換わらない時がある。読み込みと書き込みのfを変更
#          04/06    clearNullBoundaryFieldsを追加（空patchのクリア）
#          06/01    setSurfaceFeatureExtractDictを追加
#          07/13    setFieldsDictのdefaultの内容を修正（boxToCellを追加）
#

import os
import glob
import re
import getFoamContents
import pyTreeFoam
from editBoundaryConditionsDialog import readConfigData as readGridEditorConfig


workdir = ""
Pname = []


#
#  makeRegionProperties
#    regionPropertiesを作成・保存
def makeRegionProperties(caseDir, fluidRegions, solidRegions):
    config = pyTreeFoam.readConfigTreeFoam()
    OFversion = config[0]
    if OFversion >= "2.2.0":
        #version 2.2.0以降の場合
        #foamFile作成
        foamFile = makeFoamHeaderVersion(OFversion)
        foamFile += makeFoamFile("2.2", "ascii", "dictionary",
                    "constant", "regionProperties")
        footer = makeFooter()

        #regionPropertiesの内容作成
        contents = "regions\n(\n"
        contents += "    fluid       ( "
        for name in fluidRegions:
            contents += name + " "
        contents += ")\n"

        contents += "    solid       ( "
        for name in solidRegions:
            contents += name + " "
        contents += ")\n);\n"
    else:
        #version 2.1.1以前の場合
        #foamFile作成
        foamFile = makeFoamHeaderVersion(OFversion)
        foamFile += makeFoamFile("2.0", "ascii", "dictionary",
                    "constant", "regionProperties")
        footer = makeFooter()

        #regionPropertiesの内容作成
        contents = "fluidRegionNames ( "
        for name in fluidRegions:
            contents += name + " "
        contents += ");\n\n"
        contents += "solidRegionNames ( "
        for name in solidRegions:
            contents += name + " "
        contents += ");\n"

    #書き込み
    contentsDict = foamFile + contents + footer
    fileName = caseDir + "/constant/regionProperties"
    f = open(fileName, "w")
    f.write(contentsDict)
    f.close()


#
#  setSurfaceFeatureExtractDict
#    defaultのsurfaceFeatureExtractDictを作成する
def setSurfaceFeatureExtractDict():
    cont = (
"""xxxx.stl         //stlファイル名。複数ある場合は、同じセットを追記。
{
    // How to obtain raw features (extractFromFile || extractFromSurface)
    extractionMethod    extractFromSurface;

    extractFromSurfaceCoeffs
    {
        // Mark edges whose adjacent surface normals are at an angle less
        // than includedAngle as features
        // - 0  : selects no edges
        // - 180: selects all edges
        includedAngle   150;
    }

    subsetFeatures
    {
        // Keep nonManifold edges (edges with >2 connected faces)
        nonManifoldEdges       no;

        // Keep open edges (edges with 1 connected face)
        openEdges       yes;
    }

    // Write options

        // Write features to obj format for postprocessing
        writeObj                yes;
}
"""
        )
    return cont

#
#  setMachinesDefault
#    defaultのmachinesを作成する
#
def setMachinesDefault():
    wdir = os.getcwd()
    cont = makeMachinesDefault()
    fileName = "./machines"
    f=open(fileName, "w")
    f.write(cont)
    f.close()

def makeMachinesDefault():
    cont = """#  subDomain名とcpu数を記述します
#  subDomain名は、「/etc/hosts」に記述されているhost名を記述
#
#入力例：
#localhost cpu=4
#host1 cpu=2
#host2

localhost cpu=4
"""
    return cont


#
#  setDecomposeParDictDefault
#    defaultのdecomposeParDictを作成する
#
def setDecomposeParDictDefault():
    wdir = os.getcwd()
    cont = makeDecomposeParDictDefault()
    fileName = wdir + "/system/decomposeParDict"
    f=open(fileName, "w")
    f.write(cont)
    f.close()

def makeDecomposeParDictDefault():
    cont = makeFoamHeader()
    loc = "system"
    obj = "decomposeParDict"
    foamFile = makeFoamFile("2.0", "ascii", "dictionary", loc, obj )
    cont = cont + foamFile
    a = (
"""
numberOfSubdomains 4;

//- Keep owner and neighbour on same processor for faces in zones:
// preserveFaceZones (heater solid1 solid3);

//- Keep owner and neighbour on same processor for faces in patches:
//  (makes sense only for cyclic patches)
//preservePatches (cyclic_left_right);


method          scotch;
// method          hierarchical;
// method          simple;
// method          scotch;
// method          metis;
// method          manual;

simpleCoeffs
{
    n               ( 2 2 1 );
    delta           0.001;
}

hierarchicalCoeffs
{
    n               ( 1 1 1 );
    delta           0.001;
    order           xyz;
}

/*
scotchCoeffs
{
    processorWeights ( 1 1 1 1 );
}
*/

metisCoeffs
{
    processorWeights ( 1 1 1 1 );
}

manualCoeffs
{
    dataFile        "";
}

distributed     no;

roots           ( );
//// Is the case distributed
//distributed     yes;
//// Per slave (so nProcs-1 entries) the directory above the case.
//roots           
//(
//    "/tmp"
//    "/tmp"
//);

// ************************************************************************* //
"""
        )
    cont = cont + a
    return cont
    

#
#  setFieldsDictDefault
#    defaultのsetFieldsDictを作成する
#
def setFieldsDictDefault():
    wdir = os.getcwd()
    files = glob.glob(wdir + "/system")
    if len(files) != 0:
        #setFieldsDictの作成
        cont = makeSetFieldsDictDefault()
        fileName = "./system/setFieldsDict"
        f=open(fileName,"w")
        f.write(cont)
        f.close
    else:
        print "systemフォルダがないので、「setFieldsDict」が作れません。"

def makeSetFieldsDictDefault():
    cont = makeFoamHeader()
    location = "system"
    foamFile = makeFoamFile("2.0", "ascii", "dictionary", location, "setFieldsDict" )
    cont = cont + foamFile
    a = (
'''defaultFieldValues
(
    volScalarFieldValue xxxxx 0                 // scalar
    volVectorFieldValue yyyyy (0 0 0)           // vector
);

regions
(
    cellToCell
    {
        set cellset_name1;                     //cellSetName
        fieldValues
        (
            volScalarFieldValue xxxxx 10
            volVcalarFieldValue yyyyy (1 1 1)
        );
    }

    boxToCell
    {
        box (0 0 0) (1 1 1);                     //cellSetName
        fieldValues
        (
            volScalarFieldValue xxxxx 1
            volVcalarFieldValue yyyyy (2 2 2)
        );
    }
);

// ************************************************************************* //
'''
        )
    cont = cont + a
    return cont


#
#  controlDict
#    controlDictの内容を書き換える
#    items: [[item, value], [item, value], ...]
def controlDict(wdir, items):
    fileName = wdir + "/controlDict"
    f = open(fileName)
    contents = f.readlines()
    f.close()
    for item in items:
        n=0
        while n < len(contents):
            try:
                i = contents[n].index(item[0])
                if i == 0:
                    line = exchangeValue(item[1], contents[n])
                    contents[n] = line
                n=n+1
            except:
                n=n+1
    f = open(fileName, "w")
    for line in contents:
        f.write(line)
    f.close()
    
def exchangeValue(value, cont):
    a = cont.split()
    i = cont.index(a[1])
    line = cont[:i] + value + ";" + cont[i+len(a[1]):]
    return line


#
# makeFoamHeaderVersion
#
def makeFoamHeaderVersion(version):
    a=(
"""/*--------------------------------*- C++ -*----------------------------------*\\
| =========                 |                                                 |
| \\\\      /  F ield         | OpenFOAM: The Open Source CFD Toolbox           |
|  \\\\    /   O peration     | Version:  """ + version + """                                 |
|   \\\\  /    A nd           | Web:      www.OpenFOAM.org                      |
|    \\\\/     M anipulation  |                                                 |
\*---------------------------------------------------------------------------*/
"""
      )
    return a
    
#
# makeFoamHeader
#
def makeFoamHeader():
    a=(
"""/*--------------------------------*- C++ -*----------------------------------*\\
| =========                 |                                                 |
| \\\\      /  F ield         | OpenFOAM: The Open Source CFD Toolbox           |
|  \\\\    /   O peration     | Version:  1.6.x                                 |
|   \\\\  /    A nd           | Web:      www.OpenFOAM.org                      |
|    \\\\/     M anipulation  |                                                 |
\*---------------------------------------------------------------------------*/
"""
      )
    return a

#
#  makeFoamFile
#
def makeFoamFile(version, format, className, location, objectName):
    a=  "FoamFile\n"
    a=a+"{\n"
    a=a+"    version     " + version + ";\n"
    a=a+"    format      " + format + ";\n"
    a=a+"    class       " + className + ";\n"
    a=a+'    location    "' + location + '";\n'
    a=a+"    object      " + objectName + ";\n"
    a=a+"}\n"
    a=a+"// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //\n"
    a=a+"\n"
    return a

# makeCellZonesMiddle
def makeCellZonesMiddle():
    a=  "    type cellZone;\n"
    a=a+"cellLabels      List<label>\n"
    return a

# makeFaceZonesMiddle
def makeFaceZonesMiddle():
    a=  "    type faceZone;\n"
    a=a+"faceLabels      List<label>\n"
    return a

# makeFooter
def makeFooter():
    a="\n//************************************************************************* //\n"
    return a

#
#  clearNullBoundaryFields
#
#     空白patchのみのboundaryFieldのクリア
#       filedDir:       各fieldのDir　 例(.../barCut/0)
#       polyMeshDir:    polyMeshのDir　例(.../barCut/constant)
#       Flist:          クリアするFieldのみのlist [field1, field2, ...]
def clearNullBoundaryFields(fieldDir, polyMeshDir, Flist):
    if len(Flist) == 0:
        return
    # patch name の取得
    PnameList = getFoamContents.PatchNameFromBoundary(polyMeshDir)
    if PnameList != None:
        Pname = []
        for name in PnameList:
             Pname.append(name[0])
        # boundary field の作成
        zero = "type    zeroGradient;"
        [dummy, patches, Bcont] = pyTreeFoam.getFieldsPatchesName_sub(
                                    fieldDir, Flist)
        #空patchのチェック
        setFlag = 0
        print "以下の空patchを「zeroGradient」で定義します。"
        for newPatch in Pname:
            for oldPatch in patches:
                same = "no"
                if newPatch == oldPatch:
                    same = "yes"
                    break
            if same == "no":
                setFlag = 1
                print "  ", newPatch
        if setFlag == 0:
            print "  空patchはありません。"
        else:
            [dummy, newBcont] = setNullBoundaryField(Flist, Pname, patches, Bcont)
            error = makeNullBoundaryFields(fieldDir, Flist, Pname, newBcont)

def setNullBoundaryField(fields, newPatches, patches, Bcont):
    newBcontents = []
    f=0
    for field in fields:
        newBcont = []
        for newPatch in newPatches:
            same = 0
            i=0
            for patch in patches:
                if newPatch == patch:
                    value = pyTreeFoam.reformTabContents(Bcont[f][i] + "\n")
                    newBcont.append(value)
                    same = 1
                    break
                i += 1
            if same == 0:
                value = pyTreeFoam.reformTabContents("type zeroGradient;\n")
                newBcont.append(value)
        newBcontents.append(newBcont)
        f += 1
    return [fields, newBcontents]

def makeNullBoundaryFields(fieldDir, fields, patches, Bconts):
    #patchNameを整形（空白追加）
    patchesSp = []
    for patch in patches:
        patchesSp.append("    " + patch)
    #各fieldのboundaryFieldを作成
    [a1, a2, a3, nMaxLines] = readGridEditorConfig()
    i=0
    mess = ""
    while i<len(fields):
        #fieldをオープン
        fileName = fieldDir + "/" + fields[i]
        contents = getFoamContents.readField(fileName, nMaxLines)
        #patchDataから「boundaryField」を作成
        newBoundary = pyTreeFoam.makeBoundaryField(patchesSp, Bconts[i])
        #「boundaryField」を置き換える
        newContents = pyTreeFoam.replaceBoundaryField(newBoundary, contents)
        if newContents != "":
            getFoamContents.writeField(fileName, newContents)
        else:
            print "error:", fields[i], "が置き換えできませんでした。"
            mess += fields[i] + ","
        i += 1
    if mess == "":
        error = ["OK", ""]
    else:
        error = ["NG", mass[:-1] + u"が書き込めません。"]
    return error

#
#  clearBoundaryFields
#
#     boundaryFieldのクリア
#       filedDir:       各fieldのDir
#       polyMeshDir:    polyMeshのDir
#       Flist:          クリアするFieldのみのlist [field1, field2, ...]
def clearBoundaryFields(fieldDir, polyMeshDir, Flist):
    # patch name の取得
    PnameList = getFoamContents.PatchNameFromBoundary(polyMeshDir)
    if PnameList != None:
        Pname = []
        for name in PnameList:
             Pname.append(name[0])
        # boundary field の作成
        Bcont = "type    zeroGradient;"
        cont = createBoundary(Pname, Bcont)
        # field の作成
        remakeBoundaryFields(fieldDir, Flist, cont)

#
#  clearInternalFields
#
def clearInternalFields(fieldDir, polyMeshDir, Flist):
    contAns = []
    if len(Flist) != 0:
        print "internal field をクリアします..."
        [a1, a2, a3, nMaxLines] = readGridEditorConfig()
        for name in Flist:
            print "    " + name + "..."
            #fileName = getFoamContents.checkFileName(fieldDir + "/" + name)
            fileName = fieldDir + "/" + name
            cont = getFoamContents.readField(fileName, nMaxLines)
            p = getFoamContents.skipFoamFileMem(cont, 0)
            n = cont[p:].find("internalField")
            if n >= 0:
                ps = p + n
                n = cont[ps:].find(";")
                if n >= 0:
                    pe = ps + n + 1
                    line = cont[ps:pe]
                    newLine = clearInternalField(line)
                    newCont = cont[:ps] + newLine + cont[pe:]
                    getFoamContents.writeField(fileName, newCont)
        print "internal field をクリアしました。"

def clearInternalField(line):
    [dummy, ps] = getFoamContents.getKeywordMem(line, 0)
    [valForm, p] = getFoamContents.getKeywordMem(line, ps)
    if valForm == "nonuniform":
        valType = line[p:p+100]
        if valType.find("scalar") >= 0:
            val = "0"
        elif valType.find("vector") >= 0:
            val = "(0 0 0)"
        elif valType.find("symmTensor") >= 0:
            val = "(0 0 0 0 0 0)"
        elif valType.find("tensor") >= 0:
            val = "(0 0 0 0 0 0 0 0 0)"
        else:
            val = "0"
        newLine = line[:ps] + " uniform " + val + ";\n"
        line = newLine
    return line


def createBoundary(Pname,Bcont):
    cont = ""
    for name in Pname:
      cont = cont + "    " + name + "\n"
      cont = cont + "    {\n"
      cont = cont + "        " + Bcont + "\n"
      cont = cont + "    }\n"
    cont = "{\n" + cont + "}\n"
    return cont

def remakeBoundaryFields(fieldDir, Flist, cont):
    fieldNames = []
    i=0
    while i < len(Flist):
        fieldNames.append(Flist[i])
        i=i+1
    remakeTergetBoundaryFields(fieldDir, fieldNames, cont)

def remakeTergetBoundaryFields(fieldDir, fieldNames, cont):
    print fieldDir, "内の各Fieldをクリアします。"
    [a1, a2, a3, nMaxLines] = readGridEditorConfig()
    for name in fieldNames:
        print "    " + name + "..."
        #fileName = getFoamContents.checkFileName(fieldDir + "/" + name)
        fileName = fieldDir + "/" + name
        fileCont = getFoamContents.readField(fileName, nMaxLines)
        ps = getFoamContents.getKeywordPointerMem("boundaryField", fileCont, 0)
        [boundaryCont, p] = getFoamContents.getKeywordContentsMem(
                            "boundaryField", fileCont, ps)
        if len(boundaryCont) != "":
            contAll = fileCont[:ps] + "boundaryField\n" + cont + fileCont[p:]
        else:
            print "      baoundaryFieldがありません。追加しました。"
            contAll = fileCont + "boundaryField\n" + cont
            contAll += "// ************************************************************************* //\n"
        getFoamContents.writeField(fileName, contAll)
    print "boundaryFieldをクリアしました。"


