#!/usr/bin/env python
# -*- coding: utf-8 -*-
#
#   splitMeshCellZones.py
#       メッシュをcellZone毎に分割する。
#       cellZone名とcellNoは、cellZonesファイル内容から取得する。
#       領域分割後、分割したファイルは、初期時間フォルダに移動する。オリジナルの初期時間
#       フォルダは、「before-region.<初期時間フォルダ>」でバックアップされる。
#
#       使い方
#       splitMeshCellZones
#
#       10/03/26    新規作成
#       11/02/25    -cellZonesOnlyに変更（domainが作成される為）
#       11/04/15    OpenFOAMの環境設定ファイルをpyTreeFoam側から読み込む
#       12/06/15    importをpyOFLauncher→pyTreeFoamに変更
#          12/16    親case/systemフォルダ内に各regionフォルダが残るので、削除した
#       13/02/22    dict内容に空白4ヶを追加
#          03/17    multiRegion：polyMeshをtimeFolderからconstantへ移動
#          05/08      ↑　constantへ移動を廃止（constantへコピー）
#          05/20    changeDict作成をOF-2.2.0に対応
#          05/21    changeDict作成を廃止。meshOperationDalog（呼出側）で作成。
#          10/12    多言語化のため、修正
#



import os
import glob
import shutil
import string
import getFoamContents
import setFoamContents
import pyTreeFoam


#
#  splitMeshRegions
#
def splitMeshRegions():
    bashrc = pyTreeFoam.getBashrcFoam()
    command = ". " + bashrc + "; splitMeshRegions -cellZonesOnly"
    os.system(command)

#
#  makeRegNameIntoConstant
#    regionNameのフォルダを作成
def makeRegNameIntoConstant(regCaseDir, timeFolder):
    regNameDir = glob.glob(regCaseDir + "/" + timeFolder + "/*")
    for name in regNameDir:
        folder = name.split("/")[-1]
        os.mkdir(regCaseDir + "/constant/" + folder)
    print _(u"\nconstantフォルダ内にregionNameのフォルダを作成しました。")

#
#  remakeBoundaryFile(regCase)
#    boundary file のpatchを修正
def remakeBoundaryFile(regCaseDir, timeFolder):
    print _(u"\nbounadaryファイルのpatchTypeを修正します。")
    regNameDir = glob.glob(regCaseDir + "/" + timeFolder + "/*")
    regNames = []
    for name in regNameDir:
        regNames.append(name.split("/")[-1])
    boundaryFiles = []
    for nameDir in regNameDir:
        boundaryFiles.append(nameDir + "/polyMesh/boundary")
    for boundary in boundaryFiles:
        f=open(boundary)
        contents = []
        for line in f.readlines():
            contents.append(line)
        f.close()
        for beforeName in regNames:
            for afterName in regNames:
                patch = beforeName + "_to_" + afterName
                i=0
                while i<len(contents):
                    if (string.find(contents[i], patch) >= 0):
                        flag = 0
                        while i<len(contents) and flag < 2:
                            n = string.find(contents[i], "region0")
                            m = string.find(contents[i], "none")
                            if n>=0:
                                contents[i] = contents[i][:n] + afterName + contents[i][n+7:]
                                flag = flag + 1
                            if m>=0:
                                rePatch = afterName + "_to_" + beforeName
                                contents[i] = contents[i][:m] + rePatch + contents[i][m+4:]
                                flag = flag + 1
                            i=i+1
                    i=i+1
        regName = boundary.split("/")[-3]
        print "    " + regName + _(u"の boundary を修正しました。")
        f=open(boundary,"w")
        for line in contents:
            f.write(line)
        f.close()

#
#  remakeBoundaryFileConjugate
#    boundary file をconjugate用に修正
def remakeBoundaryFileConjugate(regCaseDir, timeFolder, fluidReg):
    print _(u"\nbounadaryファイルをconjugate用に修正します。")
    regNameDir = glob.glob(regCaseDir + "/" + timeFolder + "/*")
    regNames = []
    for name in regNameDir:
        regNames.append(name.split("/")[-1])
    boundaryFiles = []
    for nameDir in regNameDir:
        boundaryFiles.append(nameDir + "/polyMesh/boundary")
    #solidRegionを取得
    solidRegs = []
    for solidReg in regNames:
        if solidReg != fluidReg:
            solidRegs.append(solidReg)
    solidRegs.sort()
    print "solidRegs=", solidRegs
    #各region毎に修正
    for boundary in boundaryFiles:
        f=open(boundary)
        contents = []
        for line in f.readlines():
            contents.append(line)
        f.close()
        #項目入替え
        i=0
        while i<len(contents):
            #type変更
            contents[i] = checkCharas(contents[i], 
                            "directMappedWall", "regionCouple")
            #region項目変更
            contents[i] = checkCharas(contents[i],
                            "sampleRegion", "shadowRegion")
            #fluidRegion名変更(region0)
            contents[i] = checkWCharas(contents[i],
                            "shadowRegion", fluidReg, "region0")
            #solidRegion名変更(solid1, solid2, ...)
            contents[i] = checkWsolidCharas(contents[i],
                            "shadowRegion", solidRegs)
            #patch項目変更
            contents[i] = checkCharas(contents[i],
                            "samplePatch", "shadowPatch")
            #offSet項目変更
            contents[i] = checkOffsetLine(contents[i])
            i += 1        
        #"sampleMode"の行削除
        i=0
        repContents = []
        while i<len(contents):
            n = string.find(contents[i], "sampleMode")
            if n<0:
                repContents.append(contents[i])
            i += 1
        #終了処理(repContentsを保存)
        regName = boundary.split("/")[-3]
        print "    " + regName + _(u"の boundary を修正しました。")
        f=open(boundary,"w")
        for line in repContents:
            f.write(line)
        f.close()

def checkCharas(line, orgName, repName):
    n = string.find(line, orgName)
    if n>=0:
        line = line[:n] + repName + line[n+len(orgName):]
    return line

def checkWsolidCharas(line, orgName, repNames):
    if string.find(line, orgName) >= 0:
        i=0
        while i<len(repNames):
            n = string.find(line, repNames[i])
            if n>=0:
                line = line[:n] + "solid" + str(i+1) + line[n+len(repNames[i]):]
                break
            i += 1
    return line

def checkWCharas(line, orgName1, orgName2, repName):
    if string.find(line, orgName1) >= 0:
        n = string.find(line, orgName2)
        if n>=0:
            line = line[:n] + repName + line[n+len(orgName2):]
    return line

def checkOffsetLine(line):
    n = string.find(line, "offset")
    if n>=0:
        line = line[:n] + "attached        on;\n"
    return line

#
#  remakeBoundaryRegionCoupling
#    Region同士の境界面のboundaryをRegionCoupling、remoteFieldに設定する
def remakeBoundaryRegionCoupling(regCase, timeFolder, fields):
    wdir = regCase + "/" + timeFolder
    foldersFiles = pyTreeFoam.getFoldersFiles(wdir)
    regNames = foldersFiles[0]
    #region毎に処理
    for regName in regNames:
        regDir = wdir + "/" + regName
        for field in fields:
            fileName = regDir + "/" + field
            f = open(fileName)
            contents = f.readlines()
            f.close()
            #patchTypeをregionCouplingに変更
            i=0
            while i<len(contents)-2:
                n = string.find(contents[i], "_to_")
                m = string.find(contents[i+2], "zeroGradient")
                if n>=0 and m>=0:
                    contents[i+2] = checkCharas(contents[i+2],
                                    "zeroGradient", "regionCoupling")
                    i += 2
                i += 1
            #remoteFieldを追加
            i=0
            repContents = []
            while i<len(contents):
                repContents.append(contents[i])
                if string.find(contents[i], "regionCoupling") >= 0:
                    addLine = "        remoteField     " + field + ";\n"
                    repContents.append(addLine)
                i += 1
            #修正内容を書込
            f = open(fileName, "w")
            for line in repContents:
                f.write(line)
            f.close()

#
#  remakeBoundaryZeroGradient
#    各regionのbaundary（calculatedのみ）をzeroGradientに書き換える
def remakeBoundaryZeroGradient(regCaseDir, timeFolder):
    regNameDir = glob.glob(regCaseDir + "/" + timeFolder + "/*")
    regNames = []
    for name in regNameDir:
        regNames.append(name.split("/")[-1])
    for nameDir in regNameDir:
        fields = glob.glob(nameDir + "/*")
        for field in fields:
            if os.path.isfile(field) == True:
                fileName = field
                cont = getFoamContents.readField(fileName, 100)
                p = getFoamContents.getKeywordPointerMem("boundaryField", cont, 0)
                n = 0
                while n>=0:
                    n = cont[p:].find("calculated")
                    if n>=0:
                        p += n
                        cont = cont[:p] + "zeroGradient" + cont[p+len("calculated"):]
                getFoamContents.writeField(fileName, cont)
    print _(u"\n各RegionのboundaryFieldをzeroGradientに修正しました。")


#
#  copyFvschemesFvsolution
#    各regionにfvSchemes, fvSolutionをコピーする
def copyFvschemesFvsolution(regCaseDir, timeFolder):
    regNameDir = glob.glob(regCaseDir + "/" + timeFolder + "/*")
    regNames = []
    for name in regNameDir:
        regNames.append(name.split("/")[-1])
    regNames.sort()
    for regName in regNames:
        regSys = regCaseDir + "/system/" + regName
        os.system("rm " + regSys + "/*")
        source = regCaseDir + "/system/fvSchemes*"
        copy = regCaseDir + "/system/" + regName + "/"
        os.system("cp " + source + " " + copy)
        source = regCaseDir + "/system/fvSolution*"
        copy = regCaseDir + "/system/" + regName + "/"
        os.system("cp " + source + " " + copy)
    print _(u"\nfvSchemes, fvSolutionを各regionにコピーしました。")

#
#  delFvschemesFvsolution
#    親case/system内のregionフォルダを削除
def delFvschemesFvsolution(caseDir, timeFolder):
    regNameDir = glob.glob(caseDir + "/regCase/" + timeFolder + "/*")
    regNames = []
    for name in regNameDir:
        regNames.append(name.split("/")[-1])
    regNames.sort()
    for regName in regNames:
        delFolder = caseDir + "/system/" + regName
        shutil.rmtree(delFolder)

#
#  movePolyMeshToConstant
#    timeFolder内のpolyMeshをconstantに移動
def movePolyMeshToConstant(regCaseDir, timeFolder):
    [regNames, files] = pyTreeFoam.getFoldersFiles(regCaseDir + "/" + timeFolder)
    for region in regNames:
        source = regCaseDir + "/" + timeFolder + "/" + region + "/polyMesh"
        copy = regCaseDir + "/constant/" + region + "/polyMesh"
        shutil.copytree(source, copy)
        #shutil.rmtree(source)

#
#  createRegCase
#    multiRegion用、conjugate用にcaseを作成
def createRegCase(flag):
    print _(u"出来上がったregionを整形します。")
    caseDir = os.getcwd()
    timeFolders = pyTreeFoam.getTimeFolders(caseDir)
    if len(timeFolders) == 2:
        regCaseDir = caseDir + "/regCase"
        if len(glob.glob(regCaseDir)) != 0:
            shutil.rmtree(regCaseDir)
        os.mkdir(regCaseDir)
        src = caseDir + "/system"
        dst = regCaseDir + "/system"
        shutil.copytree(src,dst)
        src = caseDir + "/constant"
        dst = regCaseDir + "/constant"
        shutil.copytree(src,dst)
        src = caseDir + "/" + timeFolders[1]
        dst = regCaseDir + "/" + timeFolders[0]
        shutil.copytree(src,dst)
        shutil.rmtree(src)
        #regNameのフォルダをconstant内に作成
        makeRegNameIntoConstant(regCaseDir, timeFolders[0])
        #boundaryファイルのpatchTypeを修正
        remakeBoundaryFile(regCaseDir, timeFolders[0])
        #各RegionのboundaryFieldをzeroGradientに変更
        remakeBoundaryZeroGradient(regCaseDir, timeFolders[0])
        #multiRegion用に修正
        if flag == "reg":
            #changeDictionaryAllRegionsDictを作成
            #makeChangeDictionaryAllRegionsDict(regCaseDir, timeFolders[0])
            #polyMeshをconstant内にコピー
            movePolyMeshToConstant(regCaseDir, timeFolders[0])
        #各regionにfvSchemes,fvSolutionをコピーする。
        copyFvschemesFvsolution(regCaseDir, timeFolders[0])
        #親case/system内のregionフォルダを削除する。
        delFvschemesFvsolution(caseDir, timeFolders[0])
        error = ["OK", ""]
    else:    
        msg = _(u"error: 時間フォルダがないか、領域分割できていません。")
        error = ["NG", msg]
        print msg 
    return error


#  conjugate用にcaseを作成
def RunConjugate():
    splitMeshRegions()
    error = createRegCase("conj")
    return error

#  multiRegion用にcaseを作成
def Run():
    splitMeshRegions()
    error = createRegCase("reg")
    return error



if __name__ == "__main__":

    splitMeshRegions()
    createBackupFile()

